@@ -30,9 +30,9 @@
 #include <string.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
+#include <camel/camel.h>
 #include <unique/unique.h>
 #include <dbus/dbus-glib.h>
-#include <camel/camel-object.h>
 #include <libedataserver/e-source.h>
 #include <libedataserverui/e-passwords.h>
 
@@ -45,12 +45,8 @@
 gint
 main (gint argc, gchar **argv)
 {
-	GtkIconTheme *icon_theme;
 	AlarmNotify *alarm_notify_service;
 	UniqueApp *app;
-#ifdef G_OS_WIN32
-	gchar *path;
-#endif
 
 	bindtextdomain (GETTEXT_PACKAGE, EVOLUTION_LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -59,13 +55,6 @@ main (gint argc, gchar **argv)
 	g_thread_init (NULL);
 	dbus_g_thread_init ();
 
-#ifdef G_OS_WIN32
-	path = g_build_path (";", _e_get_bindir (), g_getenv ("PATH"), NULL);
-
-	if (!g_setenv ("PATH", path, TRUE))
-		g_warning ("Could not set PATH for Evolution Alarm Notifier");
-#endif
-
 	gtk_init (&argc, &argv);
 
 	app = unique_app_new ("org.gnome.EvolutionAlarmNotify", NULL);
@@ -82,9 +71,6 @@ main (gint argc, gchar **argv)
 	/* Initialize Camel's type system. */
 	camel_object_get_type();
 
-	icon_theme = gtk_icon_theme_get_default ();
-	gtk_icon_theme_append_search_path (icon_theme, EVOLUTION_ICONDIR);
-
 	gtk_main ();
 
 	if (alarm_notify_service != NULL)
