@@ -202,25 +202,12 @@ static void
 task_editor_constructed (GObject *object)
 {
 	TaskEditorPrivate *priv;
-	EShellSettings *shell_settings;
-	EShell *shell;
 
 	priv = TASK_EDITOR_GET_PRIVATE (object);
 
-	shell = comp_editor_get_shell (COMP_EDITOR (object));
-	shell_settings = e_shell_get_shell_settings (shell);
-
 	e_binding_new (
 		object, "client",
 		priv->model, "client");
-
-	e_binding_new (
-		shell_settings, "cal-free-busy-template",
-		priv->model, "free-busy-template");
-
-	e_binding_new (
-		shell_settings, "cal-timezone",
-		priv->model, "timezone");
 }
 
 static void
@@ -320,6 +307,7 @@ task_editor_init (TaskEditor *te)
 	CompEditor *editor = COMP_EDITOR (te);
 	GtkUIManager *ui_manager;
 	GtkActionGroup *action_group;
+	GtkWidget *content_area;
 	const gchar *id;
 	GError *error = NULL;
 
@@ -344,8 +332,10 @@ task_editor_init (TaskEditor *te)
 		G_CALLBACK(gtk_widget_hide), NULL);
 
 	te->priv->task_details_page = task_details_page_new (editor);
+	content_area = gtk_dialog_get_content_area (
+		GTK_DIALOG (te->priv->task_details_page));
 	gtk_container_add (
-		GTK_CONTAINER (GTK_DIALOG (te->priv->task_details_window)->vbox),
+		GTK_CONTAINER (content_area),
 		comp_editor_page_get_widget ((CompEditorPage *) te->priv->task_details_page));
 	gtk_widget_show_all (gtk_bin_get_child (GTK_BIN (te->priv->task_details_window)));
 	comp_editor_append_page (
