@@ -33,7 +33,6 @@
 #include <e-util/e-util.h>
 #include <e-util/e-categories-config.h>
 #include "calendar-config.h"
-#include <camel/camel-mime-filter-tohtml.h>
 
 #define E_CAL_COMPONENT_PREVIEW_GET_PRIVATE(obj) \
 	(G_TYPE_INSTANCE_GET_PRIVATE \
@@ -72,7 +71,9 @@ clear_comp_info (ECalComponentPreview *preview)
 /* Stores information about actually shown component and
    returns whether component in the preview changed */
 static gboolean
-update_comp_info (ECalComponentPreview *preview, ECal *ecal, ECalComponent *comp)
+update_comp_info (ECalComponentPreview *preview,
+                  ECal *ecal,
+                  ECalComponent *comp)
 {
 	ECalComponentPreviewPrivate *priv;
 	gboolean changed;
@@ -399,14 +400,8 @@ cal_component_preview_class_init (ECalComponentPreviewClass *class)
 static void
 cal_component_preview_init (ECalComponentPreview *preview)
 {
-	GtkHTML *html;
-
 	preview->priv = E_CAL_COMPONENT_PREVIEW_GET_PRIVATE (preview);
 
-	html = GTK_HTML (preview);
-	gtk_html_set_default_content_type (html, "charset=utf-8");
-	gtk_html_load_empty (html);
-
 	preview->priv->zone = icaltimezone_get_utc_timezone ();
 }
 
