@@ -2414,21 +2414,36 @@ print_date_label (GtkPrintContext *context, ECalComponent *comp, ECal *client,
 	if (start > 0)
 		write_label_piece (start, buffer, 1024, NULL, NULL);
 
-	if (end > 0 && start > 0)
+	if (end > 0 && start > 0) {
+		/* Translators: This is part of "START to END" text,
+		 * where START and END are date/times. */
 		write_label_piece (end, buffer, 1024, _(" to "), NULL);
+	}
 
 	if (complete > 0) {
-		if (start > 0)
+		if (start > 0) {
+			/* Translators: This is part of "START to END
+			 * (Completed COMPLETED)", where COMPLETED is a
+			 * completed date/time. */
 			write_label_piece (complete, buffer, 1024, _(" (Completed "), ")");
-		else
+		} else {
+			/* Translators: This is part of "Completed COMPLETED",
+			 * where COMPLETED is a completed date/time. */
 			write_label_piece (complete, buffer, 1024, _("Completed "), NULL);
+		}
 	}
 
 	if (due > 0 && complete == 0) {
-		if (start > 0)
+		if (start > 0) {
+			/* Translators: This is part of "START (Due DUE)",
+			 * where START and DUE are dates/times. */
 			write_label_piece (due, buffer, 1024, _(" (Due "), ")");
-		else
+		} else {
+			/* Translators: This is part of "Due DUE",
+			 * where DUE is a date/time due the event
+			 * should be finished. */
 			write_label_piece (due, buffer, 1024, _("Due "), NULL);
+		}
 	}
 
 	print_text_size_bold (context, buffer, PANGO_ALIGN_LEFT,
