@@ -24,9 +24,7 @@
 #ifndef E_MSG_COMPOSER_H
 #define E_MSG_COMPOSER_H
 
-#include <camel/camel-internet-address.h>
-#include <camel/camel-mime-message.h>
-#include <camel/camel-session.h>
+#include <camel/camel.h>
 #include <libedataserver/e-account.h>
 #include <libebook/e-destination.h>
 #include <gtkhtml-editor.h>
@@ -139,9 +137,6 @@ void		e_msg_composer_add_message_attachments
 						 gboolean just_inlines);
 
 void		e_msg_composer_request_close	(EMsgComposer *composer);
-gboolean	e_msg_composer_can_close	(EMsgComposer *composer,
-						 gboolean can_save_draft);
-
 EMsgComposer *	e_msg_composer_load_from_file	(const gchar *filename);
 void		e_msg_composer_check_autosave	(GtkWindow *parent);
 
