@@ -35,8 +35,6 @@
 
 #include <glib/gi18n.h>
 
-#include <camel/camel-file-utils.h>
-
 #include "mail-config.h"
 #include "mail-session.h"
 #include "mail-tools.h"
@@ -49,10 +47,8 @@
 #include "em-folder-utils.h"
 #include "em-event.h"
 
-#include <camel/camel-folder.h>
-#include <camel/camel-vee-store.h>
-
 #include "e-mail-local.h"
+#include "shell/e-shell.h"
 
 #define d(x)
 
@@ -108,7 +104,7 @@ store_info_free (EMFolderTreeModelStoreInfo *si)
 	camel_object_remove_event (si->store, si->unsubscribed_id);
 
 	g_free (si->display_name);
-	camel_object_unref (si->store);
+	g_object_unref (si->store);
 	gtk_tree_row_reference_free (si->row);
 	g_hash_table_destroy (si->full_hash);
 	g_free (si);
@@ -120,12 +116,16 @@ folder_tree_model_sort (GtkTreeModel *model,
                         GtkTreeIter *b,
                         gpointer user_data)
 {
+	EShell *shell;
 	gchar *aname, *bname;
 	CamelStore *store;
 	gboolean is_store;
 	guint32 aflags, bflags;
 	gint rv = -2;
 
+	/* XXX Pass the EShell in as user_data. */
+	shell = e_shell_get_default ();
+
 	gtk_tree_model_get (
 		model, a,
 		COL_BOOL_IS_STORE, &is_store,
@@ -141,14 +141,31 @@ folder_tree_model_sort (GtkTreeModel *model,
 	if (is_store) {
 		/* On This Computer is always first, and Search Folders
 		 * is always last. */
-		if (!strcmp (aname, _("On This Computer")))
-			rv = -1;
-		else if (!strcmp (bname, _("On This Computer")))
-			rv = 1;
-		else if (!strcmp (aname, _("Search Folders")))
-			rv = 1;
-		else if (!strcmp (bname, _("Search Folders")))
-			rv = -1;
+		if (e_shell_get_express_mode (shell)) {
+			if (!strcmp (aname, _("On This Computer")) &&
+				!strcmp (bname, _("Search Folders")))
+				rv = -1;
+			else if (!strcmp (bname, _("On This Computer")) &&
+				!strcmp (aname, _("Search Folders")))
+				rv = 1;
+			else if (!strcmp (aname, _("On This Computer")))
+				rv = 1;
+			else if (!strcmp (bname, _("On This Computer")))
+				rv = -1;
+				else if (!strcmp (aname, _("Search Folders")))
+				rv = 1;
+			else if (!strcmp (bname, _("Search Folders")))
+				rv = -1;
+		} else {
+			if (!strcmp (aname, _("On This Computer")))
+				rv = -1;
+			else if (!strcmp (bname, _("On This Computer")))
+				rv = 1;
+			else if (!strcmp (aname, _("Search Folders")))
+				rv = 1;
+			else if (!strcmp (bname, _("Search Folders")))
+				rv = -1;
+		}
 	} else if (store == vfolder_store) {
 		/* UNMATCHED is always last. */
 		if (aname && !strcmp (aname, _("UNMATCHED")))
@@ -209,13 +226,15 @@ account_changed_cb (EAccountList *accounts,
 	if (!(provider->flags & CAMEL_PROVIDER_IS_STORAGE))
 		return;
 
-	if (!(store = (CamelStore *) camel_session_get_service (session, uri, CAMEL_PROVIDER_STORE, &ex))) {
+	store = (CamelStore *) camel_session_get_service (
+		session, uri, CAMEL_PROVIDER_STORE, &ex);
+	if (store == NULL) {
 		camel_exception_clear (&ex);
 		return;
 	}
 
 	em_folder_tree_model_add_store (model, store, account->name);
-	camel_object_unref (store);
+	g_object_unref (store);
 }
 
 static void
@@ -601,7 +620,8 @@ em_folder_tree_model_set_folder_info (EMFolderTreeModel *model,
 	tree_store = GTK_TREE_STORE (model);
 
 	if (!fully_loaded)
-		load = fi->child == NULL && !(fi->flags & (CAMEL_FOLDER_NOCHILDREN | CAMEL_FOLDER_NOINFERIORS));
+		load = (fi->child == NULL) && !(fi->flags &
+			(CAMEL_FOLDER_NOCHILDREN | CAMEL_FOLDER_NOINFERIORS));
 
 	path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), iter);
 	uri_row = gtk_tree_row_reference_new (GTK_TREE_MODEL (model), path);
@@ -613,12 +633,14 @@ em_folder_tree_model_set_folder_info (EMFolderTreeModel *model,
 	g_hash_table_insert (
 		si->full_hash, g_strdup (fi->full_name), path_row);
 
-	/* HACK: if we have the folder, and its the outbox folder, we need the total count, not unread */
-	/* HACK2: We do the same to the draft folder */
-	/* This is duplicated in mail-folder-cache too, should perhaps be functionised */
+	/* XXX If we have the folder, and its the Outbox folder, we need
+	 *     the total count, not unread.  We do the same for Drafts. */
+
+	/* XXX This is duplicated in mail-folder-cache too, should perhaps
+	 *     be functionised. */
 	unread = fi->unread;
-	if (mail_folder_cache_get_folder_from_uri(mail_folder_cache_get_default (),
-						fi->uri, &folder) && folder) {
+	if (mail_folder_cache_get_folder_from_uri (
+		mail_folder_cache_get_default (), fi->uri, &folder) && folder) {
 		is_drafts = em_utils_folder_is_drafts (folder, fi->uri);
 
 		if (is_drafts || em_utils_folder_is_outbox (folder, fi->uri)) {
@@ -634,10 +656,11 @@ em_folder_tree_model_set_folder_info (EMFolderTreeModel *model,
 			unread = total > 0 ? total : 0;
 		}
 
-		camel_object_unref(folder);
+		g_object_unref (folder);
 	}
 
-	/* TODO: maybe this should be handled by mail_get_folderinfo (except em-folder-tree doesn't use it, duh) */
+	/* TODO Maybe this should be handled by mail_get_folderinfo
+	 *      (except em-folder-tree doesn't use it, duh) */
 	flags = fi->flags;
 	name = fi->name;
 	if (si->store == e_mail_local_get_store ()) {
@@ -700,8 +723,12 @@ em_folder_tree_model_set_folder_info (EMFolderTreeModel *model,
 		COL_BOOL_IS_DRAFT, is_drafts,
 		-1);
 
-	target = em_event_target_new_custom_icon (em_event_peek(), tree_store, iter, fi->full_name, EM_EVENT_CUSTOM_ICON);
-	e_event_emit ((EEvent *)em_event_peek (), "folder.customicon", (EEventTarget *) target);
+	target = em_event_target_new_custom_icon (
+		em_event_peek (), tree_store, iter,
+		fi->full_name, EM_EVENT_CUSTOM_ICON);
+	e_event_emit (
+		(EEvent *) em_event_peek (), "folder.customicon",
+		(EEventTarget *) target);
 
 	if (unread != ~0)
 		gtk_tree_store_set (
@@ -778,7 +805,7 @@ folder_subscribed (CamelStore *store,
 		goto done;
 
 	/* get our parent folder's path */
-	dirname = alloca(strlen(fi->full_name)+1);
+	dirname = g_alloca(strlen(fi->full_name)+1);
 	strcpy(dirname, fi->full_name);
 	p = strrchr(dirname, '/');
 	if (p == NULL) {
@@ -811,7 +838,7 @@ folder_subscribed (CamelStore *store,
 	g_signal_emit (model, signals[FOLDER_ADDED], 0, fi->full_name, fi->uri);
 
 done:
-	camel_object_unref (store);
+	g_object_unref (store);
 	camel_folder_info_free (fi);
 }
 
@@ -822,7 +849,7 @@ folder_subscribed_cb (CamelStore *store,
 {
 	CamelFolderInfo *fi;
 
-	camel_object_ref (store);
+	g_object_ref (store);
 	fi = camel_folder_info_clone (event_data);
 
 	mail_async_event_emit (
@@ -855,7 +882,7 @@ folder_unsubscribed (CamelStore *store,
 	em_folder_tree_model_remove_folders (model, si, &iter);
 
 done:
-	camel_object_unref (store);
+	g_object_unref (store);
 	camel_folder_info_free (fi);
 }
 
@@ -866,7 +893,7 @@ folder_unsubscribed_cb (CamelStore *store,
 {
 	CamelFolderInfo *fi;
 
-	camel_object_ref (store);
+	g_object_ref (store);
 	fi = camel_folder_info_clone (event_data);
 
 	mail_async_event_emit (
@@ -886,7 +913,7 @@ folder_created_cb (CamelStore *store,
 	if (camel_store_supports_subscriptions (store))
 		return;
 
-	camel_object_ref (store);
+	g_object_ref (store);
 	fi = camel_folder_info_clone (event_data);
 
 	mail_async_event_emit (
@@ -906,7 +933,7 @@ folder_deleted_cb (CamelStore *store,
 	if (camel_store_supports_subscriptions (store))
 		return;
 
-	camel_object_ref (store);
+	g_object_ref (store);
 	fi = camel_folder_info_clone (event_data);
 
 	mail_async_event_emit (
@@ -962,7 +989,7 @@ folder_renamed (CamelStore *store,
 	em_folder_tree_model_set_folder_info (model, &iter, si, info->new, TRUE);
 
 done:
-	camel_object_unref (store);
+	g_object_unref (store);
 
 	g_free (info->old_base);
 	camel_folder_info_free (info->new);
@@ -976,7 +1003,7 @@ folder_renamed_cb (CamelStore *store,
 {
 	CamelRenameInfo *rinfo, *info = event_data;
 
-	camel_object_ref (store);
+	g_object_ref (store);
 
 	rinfo = g_new0 (CamelRenameInfo, 1);
 	rinfo->old_base = g_strdup (info->old_base);
@@ -1031,7 +1058,7 @@ em_folder_tree_model_add_store (EMFolderTreeModel *model,
 
 	si = g_new (EMFolderTreeModelStoreInfo, 1);
 	si->display_name = g_strdup (display_name);
-	camel_object_ref (store);
+	g_object_ref (store);
 	si->store = store;
 	si->account = account;
 	si->row = gtk_tree_row_reference_copy (reference);
