@@ -42,11 +42,6 @@
 #undef interface
 #endif
 
-#include <camel/camel-stream-fs.h>
-#include <camel/camel-url-scanner.h>
-#include <camel/camel-file-utils.h>
-#include <camel/camel-string-utils.h>
-
 #include <libebook/e-book.h>
 
 #include "em-filter-editor.h"
@@ -103,7 +98,14 @@ em_utils_ask_open_many (GtkWindow *parent,
 	if (how_many < TOO_MANY)
 		return TRUE;
 
-	string = g_strdup_printf ("%d", how_many);
+	string = g_strdup_printf (
+		ngettext (
+			/* Translators: This message is shown only for ten or more messages to be opened.
+			   The %d is replaced with the actual count of messages. If you need a '%' in your text,
+			   then write it doubled, like '%%'. */
+			"Are you sure you want to open %d messages at once?",
+			"Are you sure you want to open %d messages at once?", how_many),
+		how_many);
 	proceed = em_utils_prompt_user (
 		parent, "/apps/evolution/mail/prompts/open_many",
 		"mail:ask-open-many", string, NULL);
@@ -129,6 +131,7 @@ gboolean
 em_utils_prompt_user(GtkWindow *parent, const gchar *promptkey, const gchar *tag, ...)
 {
 	GtkWidget *mbox, *check = NULL;
+	GtkWidget *container;
 	va_list ap;
 	gint button;
 	GConfClient *gconf = mail_config_get_gconf_client();
@@ -148,7 +151,8 @@ em_utils_prompt_user(GtkWindow *parent, const gchar *promptkey, const gchar *tag
 	if (promptkey) {
 		check = gtk_check_button_new_with_mnemonic (_("_Do not show this message again."));
 		gtk_container_set_border_width((GtkContainer *)check, 12);
-		gtk_box_pack_start ((GtkBox *)((GtkDialog *) mbox)->vbox, check, TRUE, TRUE, 0);
+		container = gtk_dialog_get_content_area (GTK_DIALOG (mbox));
+		gtk_box_pack_start (GTK_BOX (container), check, TRUE, TRUE, 0);
 		gtk_widget_show (check);
 	}
 
@@ -277,7 +281,7 @@ em_utils_edit_filters (GtkWidget *parent)
 	EMFilterContext *fc;
 
 	if (filter_editor) {
-		gdk_window_raise (GTK_WIDGET (filter_editor)->window);
+		gtk_window_present (GTK_WINDOW (filter_editor));
 		return;
 	}
 
@@ -405,7 +409,7 @@ em_utils_flag_for_followup (EMailReader *reader,
 			camel_message_info_from (info),
 			camel_message_info_subject (info));
 
-		camel_message_info_free(info);
+		camel_folder_free_message_info (folder, info);
 	}
 
 	/* special-case... */
@@ -419,7 +423,7 @@ em_utils_flag_for_followup (EMailReader *reader,
 			if (tags)
 				e_mail_tag_editor_set_tag_list (
 					E_MAIL_TAG_EDITOR (editor), tags);
-			camel_message_info_free (info);
+			camel_folder_free_message_info (folder, info);
 		}
 	}
 
@@ -444,7 +448,7 @@ em_utils_flag_for_followup (EMailReader *reader,
 			camel_message_info_set_user_tag (
 				info, iter->name, iter->value);
 
-		camel_message_info_free (info);
+		camel_folder_free_message_info (folder, info);
 	}
 
 	camel_folder_thaw (folder);
@@ -486,7 +490,7 @@ em_utils_flag_for_followup_clear (GtkWindow *parent, CamelFolder *folder, GPtrAr
 			camel_message_info_set_user_tag(mi, "follow-up", NULL);
 			camel_message_info_set_user_tag(mi, "due-by", NULL);
 			camel_message_info_set_user_tag(mi, "completed-on", NULL);
-			camel_message_info_free(mi);
+			camel_folder_free_message_info (folder, mi);
 		}
 	}
 	camel_folder_thaw (folder);
@@ -525,7 +529,7 @@ em_utils_flag_for_followup_completed (GtkWindow *parent, CamelFolder *folder, GP
 			tag = camel_message_info_user_tag(mi, "follow-up");
 			if (tag && tag[0])
 				camel_message_info_set_user_tag(mi, "completed-on", now);
-			camel_message_info_free(mi);
+			camel_folder_free_message_info (folder, mi);
 		}
 	}
 	camel_folder_thaw (folder);
@@ -535,23 +539,20 @@ em_utils_flag_for_followup_completed (GtkWindow *parent, CamelFolder *folder, GP
 	em_utils_uids_free (uids);
 }
 
-#include "camel/camel-stream-mem.h"
-#include "camel/camel-stream-filter.h"
-#include "camel/camel-mime-filter-from.h"
-
 /* This kind of sucks, because for various reasons most callers need to run synchronously
    in the gui thread, however this could take a long, blocking time, to run */
 static gint
 em_utils_write_messages_to_stream(CamelFolder *folder, GPtrArray *uids, CamelStream *stream)
 {
-	CamelStreamFilter *filtered_stream;
-	CamelMimeFilterFrom *from_filter;
+	CamelStream *filtered_stream;
+	CamelMimeFilter *from_filter;
 	gint i, res = 0;
 
 	from_filter = camel_mime_filter_from_new();
-	filtered_stream = camel_stream_filter_new_with_stream(stream);
-	camel_stream_filter_add(filtered_stream, (CamelMimeFilter *)from_filter);
-	camel_object_unref(from_filter);
+	filtered_stream = camel_stream_filter_new (stream);
+	camel_stream_filter_add (
+		CAMEL_STREAM_FILTER (filtered_stream), from_filter);
+	g_object_unref (from_filter);
 
 	for (i=0; i<uids->len; i++) {
 		CamelMimeMessage *message;
@@ -573,13 +574,13 @@ em_utils_write_messages_to_stream(CamelFolder *folder, GPtrArray *uids, CamelStr
 			res = -1;
 
 		g_free(from);
-		camel_object_unref(message);
+		g_object_unref (message);
 
 		if (res == -1)
 			break;
 	}
 
-	camel_object_unref(filtered_stream);
+	g_object_unref (filtered_stream);
 
 	return res;
 }
@@ -602,12 +603,12 @@ em_utils_read_messages_from_stream(CamelFolder *folder, CamelStream *stream)
 		/* NB: de-from filter, once written */
 		msg = camel_mime_message_new();
 		if (camel_mime_part_construct_from_parser((CamelMimePart *)msg, mp) == -1) {
-			camel_object_unref(msg);
+			g_object_unref (msg);
 			break;
 		}
 
 		camel_folder_append_message(folder, msg, NULL, NULL, ex);
-		camel_object_unref(msg);
+		g_object_unref (msg);
 
 		if (camel_exception_is_set (ex))
 			break;
@@ -615,7 +616,7 @@ em_utils_read_messages_from_stream(CamelFolder *folder, CamelStream *stream)
 		camel_mime_parser_step(mp, NULL, NULL);
 	}
 
-	camel_object_unref(mp);
+	g_object_unref (mp);
 	if (!camel_exception_is_set(ex))
 		res = 0;
 	camel_exception_free(ex);
@@ -634,24 +635,30 @@ em_utils_read_messages_from_stream(CamelFolder *folder, CamelStream *stream)
  * Warning: This could block the ui for an extended period.
  **/
 void
-em_utils_selection_set_mailbox(GtkSelectionData *data, CamelFolder *folder, GPtrArray *uids)
+em_utils_selection_set_mailbox (GtkSelectionData *data,
+                                CamelFolder *folder,
+                                GPtrArray *uids)
 {
+	GByteArray *byte_array;
 	CamelStream *stream;
-	GByteArray *mem_bytes;
+	GdkAtom target;
 
-	mem_bytes = g_byte_array_new ();
-	stream = camel_stream_mem_new_with_byte_array (mem_bytes);
-	if (em_utils_write_messages_to_stream(folder, uids, stream) == 0)
-		gtk_selection_data_set(data, data->target, 8,
-				       mem_bytes->data,
-				       mem_bytes->len);
+	target = gtk_selection_data_get_target (data);
 
-	camel_object_unref(stream);
+	byte_array = g_byte_array_new ();
+	stream = camel_stream_mem_new_with_byte_array (byte_array);
+
+	if (em_utils_write_messages_to_stream (folder, uids, stream) == 0)
+		gtk_selection_data_set(
+			data, target, 8,
+			byte_array->data, byte_array->len);
+
+	g_object_unref (stream);
 }
 
 /**
  * em_utils_selection_get_mailbox:
- * @data: selection data
+ * @selection_data: selection data
  * @folder:
  *
  * Receive a mailbox selection/dnd
@@ -660,50 +667,64 @@ em_utils_selection_set_mailbox(GtkSelectionData *data, CamelFolder *folder, GPtr
  * FIXME: Exceptions?
  **/
 void
-em_utils_selection_get_mailbox(GtkSelectionData *data, CamelFolder *folder)
+em_utils_selection_get_mailbox (GtkSelectionData *selection_data,
+                                CamelFolder *folder)
 {
 	CamelStream *stream;
+	const guchar *data;
+	gint length;
 
-	if (data->data == NULL || data->length == -1)
+	data = gtk_selection_data_get_data (selection_data);
+	length = gtk_selection_data_get_length (selection_data);
+
+	if (data == NULL || length == -1)
 		return;
 
 	/* TODO: a stream mem with read-only access to existing data? */
 	/* NB: Although copying would let us run this async ... which it should */
-	stream = (CamelStream *)camel_stream_mem_new_with_buffer((gchar *)data->data, data->length);
+	stream = (CamelStream *)
+		camel_stream_mem_new_with_buffer ((gchar *) data, length);
 	em_utils_read_messages_from_stream(folder, stream);
-	camel_object_unref(stream);
+	g_object_unref (stream);
 }
 
 /**
  * em_utils_selection_get_message:
- * @data:
+ * @selection_data:
  * @folder:
  *
  * get a message/rfc822 data.
  **/
 void
-em_utils_selection_get_message(GtkSelectionData *data, CamelFolder *folder)
+em_utils_selection_get_message (GtkSelectionData *selection_data,
+                                CamelFolder *folder)
 {
 	CamelStream *stream;
 	CamelException *ex;
 	CamelMimeMessage *msg;
+	const guchar *data;
+	gint length;
 
-	if (data->data == NULL || data->length == -1)
+	data = gtk_selection_data_get_data (selection_data);
+	length = gtk_selection_data_get_length (selection_data);
+
+	if (data == NULL || length == -1)
 		return;
 
 	ex = camel_exception_new();
-	stream = (CamelStream *)camel_stream_mem_new_with_buffer((gchar *)data->data, data->length);
+	stream = (CamelStream *)
+		camel_stream_mem_new_with_buffer ((gchar *)data, length);
 	msg = camel_mime_message_new();
 	if (camel_data_wrapper_construct_from_stream((CamelDataWrapper *)msg, stream) == 0)
 		camel_folder_append_message(folder, msg, NULL, NULL, ex);
-	camel_object_unref(msg);
-	camel_object_unref(stream);
+	g_object_unref (msg);
+	g_object_unref (stream);
 	camel_exception_free(ex);
 }
 
 /**
  * em_utils_selection_set_uidlist:
- * @data: selection data
+ * @selection_data: selection data
  * @uri:
  * @uids:
  *
@@ -712,9 +733,12 @@ em_utils_selection_get_message(GtkSelectionData *data, CamelFolder *folder)
  * FIXME: be nice if this could take a folder argument rather than uri
  **/
 void
-em_utils_selection_set_uidlist(GtkSelectionData *data, const gchar *uri, GPtrArray *uids)
+em_utils_selection_set_uidlist (GtkSelectionData *selection_data,
+                                const gchar *uri,
+                                GPtrArray *uids)
 {
 	GByteArray *array = g_byte_array_new();
+	GdkAtom target;
 	gint i;
 
 	/* format: "uri\0uid1\0uid2\0uid3\0...\0uidn\0" */
@@ -724,7 +748,9 @@ em_utils_selection_set_uidlist(GtkSelectionData *data, const gchar *uri, GPtrArr
 	for (i=0; i<uids->len; i++)
 		g_byte_array_append(array, uids->pdata[i], strlen(uids->pdata[i])+1);
 
-	gtk_selection_data_set(data, data->target, 8, array->data, array->len);
+	target = gtk_selection_data_get_target (selection_data);
+	gtk_selection_data_set (
+		selection_data, target, 8, array->data, array->len);
 	g_byte_array_free(array, TRUE);
 }
 
@@ -738,27 +764,37 @@ em_utils_selection_set_uidlist(GtkSelectionData *data, const gchar *uri, GPtrArr
  * Warning: Could take some time to run.
  **/
 void
-em_utils_selection_get_uidlist(GtkSelectionData *data, CamelFolder *dest, gint move, CamelException *ex)
+em_utils_selection_get_uidlist (GtkSelectionData *selection_data,
+                                CamelFolder *dest,
+                                gint move,
+                                CamelException *ex)
 {
 	/* format: "uri\0uid1\0uid2\0uid3\0...\0uidn" */
 	gchar *inptr, *inend;
 	GPtrArray *uids;
 	CamelFolder *folder;
+	const guchar *data;
+	gint length;
 
-	if (data == NULL || data->data == NULL || data->length == -1)
+	g_return_if_fail (selection_data != NULL);
+
+	data = gtk_selection_data_get_data (selection_data);
+	length = gtk_selection_data_get_length (selection_data);
+
+	if (data == NULL || length == -1)
 		return;
 
 	uids = g_ptr_array_new();
 
-	inptr = (gchar *)data->data;
-	inend = (gchar *)(data->data + data->length);
+	inptr = (gchar *) data;
+	inend = (gchar *) (data + length);
 	while (inptr < inend) {
 		gchar *start = inptr;
 
 		while (inptr < inend && *inptr)
 			inptr++;
 
-		if (start > (gchar *)data->data)
+		if (start > (gchar *) data)
 			g_ptr_array_add(uids, g_strndup(start, inptr-start));
 
 		inptr++;
@@ -769,10 +805,10 @@ em_utils_selection_get_uidlist(GtkSelectionData *data, CamelFolder *dest, gint m
 		return;
 	}
 
-	folder = mail_tool_uri_to_folder((gchar *)data->data, 0, ex);
+	folder = mail_tool_uri_to_folder((gchar *) data, 0, ex);
 	if (folder) {
 		camel_folder_transfer_messages_to(folder, uids, dest, NULL, move, ex);
-		camel_object_unref(folder);
+		g_object_unref (folder);
 	}
 
 	em_utils_uids_free(uids);
@@ -806,14 +842,16 @@ em_utils_selection_set_urilist(GtkSelectionData *data, CamelFolder *folder, GPtr
 		info = camel_folder_get_message_info(folder, uids->pdata[0]);
 		if (info) {
 			file = g_strdup(camel_message_info_subject(info));
-			camel_folder_free_message_info(folder, info);
+			camel_folder_free_message_info (folder, info);
 		}
 	}
 
 	/* TODO: Handle conflicts? */
 	if (file == NULL) {
 		/* Drop filename for messages from a mailbox */
-		file = g_strdup_printf(_("Messages from %s"), folder->name);
+		file = g_strdup_printf (
+			_("Messages from %s"),
+			camel_folder_get_name (folder));
 	}
 
 	e_filename_make_safe(file);
@@ -835,12 +873,14 @@ em_utils_selection_set_urilist(GtkSelectionData *data, CamelFolder *folder, GPtr
 		if (em_utils_write_messages_to_stream(folder, uids, fstream) == 0) {
 			/* terminate with \r\n to be compliant with the spec */
 			gchar *uri_crlf = g_strconcat(uri, "\r\n", NULL);
+			GdkAtom target;
 
-			gtk_selection_data_set(data, data->target, 8, (guchar *)uri_crlf, strlen(uri_crlf));
+			target = gtk_selection_data_get_target (data);
+			gtk_selection_data_set(data, target, 8, (guchar *)uri_crlf, strlen(uri_crlf));
 			g_free(uri_crlf);
 		}
 
-		camel_object_unref(fstream);
+		g_object_unref (fstream);
 	} else
 		close(fd);
 
@@ -864,12 +904,18 @@ em_utils_selection_get_urilist (GtkSelectionData *selection_data,
 	CamelStream *stream;
 	CamelURL *url;
 	gint fd, i, res = 0;
-	gchar **uris;
+	gchar *tmp, **uris;
+	const guchar *data;
+	gint length;
 
 	d(printf(" * drop uri list\n"));
 
-	uris = gtk_selection_data_get_uris (selection_data);
+	data = gtk_selection_data_get_data (selection_data);
+	length = gtk_selection_data_get_length (selection_data);
 
+	tmp = g_strndup ((gchar *) data, length);
+	uris = g_strsplit (tmp, "\n", 0);
+	g_free(tmp);
 	for (i=0;res == 0 && uris[i];i++) {
 		g_strstrip(uris[i]);
 		if (uris[i][0] == '#')
@@ -884,14 +930,14 @@ em_utils_selection_get_urilist (GtkSelectionData *selection_data,
 			stream = camel_stream_fs_new_with_fd(fd);
 			if (stream) {
 				res = em_utils_read_messages_from_stream(folder, stream);
-				camel_object_unref(stream);
+				g_object_unref (stream);
 			} else
 				close(fd);
 		}
 		camel_url_free(url);
 	}
 
-	g_strfreev (uris);
+	g_strfreev(uris);
 }
 
 static void
@@ -969,6 +1015,7 @@ gboolean
 em_utils_folder_is_templates (CamelFolder *folder, const gchar *uri)
 {
 	CamelFolder *local_templates_folder;
+	CamelStore *parent_store;
 	EAccountList *accounts;
 	EAccount *account;
 	EIterator *iter;
@@ -984,6 +1031,8 @@ em_utils_folder_is_templates (CamelFolder *folder, const gchar *uri)
 	if (folder == NULL || uri == NULL)
 		return FALSE;
 
+	parent_store = camel_folder_get_parent_store (folder);
+
 	accounts = e_get_account_list ();
 	iter = e_list_get_iterator ((EList *)accounts);
 	while (e_iterator_is_valid (iter)) {
@@ -991,7 +1040,7 @@ em_utils_folder_is_templates (CamelFolder *folder, const gchar *uri)
 
 		if (account->templates_folder_uri) {
 			templates_uri = em_uri_to_camel (account->templates_folder_uri);
-			if (camel_store_folder_uri_equal (folder->parent_store, templates_uri, uri)) {
+			if (camel_store_folder_uri_equal (parent_store, templates_uri, uri)) {
 				g_free (templates_uri);
 				is = TRUE;
 				break;
@@ -1020,6 +1069,7 @@ gboolean
 em_utils_folder_is_drafts(CamelFolder *folder, const gchar *uri)
 {
 	CamelFolder *local_drafts_folder;
+	CamelStore *parent_store;
 	EAccountList *accounts;
 	EAccount *account;
 	EIterator *iter;
@@ -1035,6 +1085,8 @@ em_utils_folder_is_drafts(CamelFolder *folder, const gchar *uri)
 	if (folder == NULL || uri == NULL)
 		return FALSE;
 
+	parent_store = camel_folder_get_parent_store (folder);
+
 	accounts = e_get_account_list ();
 	iter = e_list_get_iterator((EList *)accounts);
 	while (e_iterator_is_valid(iter)) {
@@ -1042,7 +1094,7 @@ em_utils_folder_is_drafts(CamelFolder *folder, const gchar *uri)
 
 		if (account->drafts_folder_uri) {
 			drafts_uri = em_uri_to_camel (account->drafts_folder_uri);
-			if (camel_store_folder_uri_equal (folder->parent_store, drafts_uri, uri)) {
+			if (camel_store_folder_uri_equal (parent_store, drafts_uri, uri)) {
 				g_free (drafts_uri);
 				is = TRUE;
 				break;
@@ -1071,6 +1123,7 @@ gboolean
 em_utils_folder_is_sent(CamelFolder *folder, const gchar *uri)
 {
 	CamelFolder *local_sent_folder;
+	CamelStore *parent_store;
 	EAccountList *accounts;
 	EAccount *account;
 	EIterator *iter;
@@ -1085,6 +1138,8 @@ em_utils_folder_is_sent(CamelFolder *folder, const gchar *uri)
 	if (folder == NULL || uri == NULL)
 		return FALSE;
 
+	parent_store = camel_folder_get_parent_store (folder);
+
 	accounts = e_get_account_list ();
 	iter = e_list_get_iterator((EList *)accounts);
 	while (e_iterator_is_valid(iter)) {
@@ -1092,7 +1147,7 @@ em_utils_folder_is_sent(CamelFolder *folder, const gchar *uri)
 
 		if (account->sent_folder_uri) {
 			sent_uri = em_uri_to_camel (account->sent_folder_uri);
-			if (camel_store_folder_uri_equal (folder->parent_store, sent_uri, uri)) {
+			if (camel_store_folder_uri_equal (parent_store, sent_uri, uri)) {
 				g_free (sent_uri);
 				is = TRUE;
 				break;
@@ -1135,7 +1190,7 @@ em_utils_folder_is_outbox(CamelFolder *folder, const gchar *uri)
 		return FALSE;
 
 	return camel_store_folder_uri_equal (
-		local_outbox_folder->parent_store,
+		camel_folder_get_parent_store (local_outbox_folder),
 		local_outbox_folder_uri, uri);
 }
 
@@ -1234,7 +1289,7 @@ em_utils_message_to_html (CamelMimeMessage *message, const gchar *credits, guint
 		camel_stream_write ((CamelStream*)mem, append, strlen (append));
 
 	camel_stream_write((CamelStream *)mem, "", 1);
-	camel_object_unref(mem);
+	g_object_unref (mem);
 
 	text = (gchar *)buf->data;
 	if (len)
@@ -1256,14 +1311,17 @@ em_utils_message_to_html (CamelMimeMessage *message, const gchar *credits, guint
 void
 em_utils_expunge_folder (GtkWidget *parent, CamelFolder *folder)
 {
-	gchar *name;
+	const gchar *description;
 
-	camel_object_get(folder, NULL, CAMEL_OBJECT_DESCRIPTION, &name, 0);
+	description = camel_folder_get_description (folder);
 
-	if (!em_utils_prompt_user ((GtkWindow *) parent, "/apps/evolution/mail/prompts/expunge", "mail:ask-expunge", name, NULL))
+	if (!em_utils_prompt_user (
+		GTK_WINDOW (parent),
+		"/apps/evolution/mail/prompts/expunge",
+		"mail:ask-expunge", description, NULL))
 		return;
 
-	mail_expunge_folder(folder, NULL, NULL);
+	mail_expunge_folder (folder, NULL, NULL);
 }
 
 /**
@@ -1939,7 +1997,7 @@ emu_remove_from_mail_cache (const GSList *addresses)
 		}
 	}
 
-	camel_object_unref (cia);
+	g_object_unref (cia);
 }
 
 void
@@ -2095,10 +2153,12 @@ static EAccount *
 guess_account_from_folder (CamelFolder *folder)
 {
 	CamelService *service;
+	CamelStore *parent_store;
 	EAccount *account;
 	gchar *source_url;
 
-	service = CAMEL_SERVICE (folder->parent_store);
+	parent_store = camel_folder_get_parent_store (folder);
+	service = CAMEL_SERVICE (parent_store);
 
 	source_url = camel_url_to_string (service->url, CAMEL_URL_HIDE_ALL);
 	account = mail_config_get_account_by_source_url (source_url);
@@ -2202,7 +2262,7 @@ em_utils_guess_account_with_recipients (CamelMimeMessage *message,
 	EAccountList *account_list;
 	GHashTable *recipients;
 	EIterator *iter;
-	const CamelInternetAddress *addr;
+	CamelInternetAddress *addr;
 	const gchar *type;
 	const gchar *key;
 
