@@ -34,8 +34,9 @@
 #include "calendar/gui/e-calendar-selector.h"
 #include "calendar/gui/misc.h"
 
-#include "e-cal-shell-backend.h"
 #include "e-cal-shell-view.h"
+#include "e-cal-shell-backend.h"
+#include "e-cal-shell-content.h"
 
 #define E_CAL_SHELL_SIDEBAR_GET_PRIVATE(obj) \
 	(G_TYPE_INSTANCE_GET_PRIVATE \
@@ -48,11 +49,21 @@ struct _ECalShellSidebarPrivate {
 
 	/* UID -> Client */
 	GHashTable *client_table;
+
+	/* The default client is for ECalModel.  It follows the
+	 * sidebar's primary selection, even if the highlighted
+	 * source is not selected.  The tricky part is we don't
+	 * update the property until the client is successfully
+	 * opened.  So the user first highlights a source, then
+	 * sometime later we update our default-client property
+	 * which is bound by an EBinding to ECalModel. */
+	ECal *default_client;
 };
 
 enum {
 	PROP_0,
 	PROP_DATE_NAVIGATOR,
+	PROP_DEFAULT_CLIENT,
 	PROP_SELECTOR
 };
 
@@ -145,6 +156,11 @@ cal_shell_sidebar_backend_error_cb (ECalShellSidebar *cal_shell_sidebar,
 	uri = e_cal_get_uri (client);
 	uri_no_passwd = get_uri_without_password (uri);
 
+	/* Translators: This string is displayed in a message dialog when
+	 *              our connection to the calendar service detects an
+	 *              out-of-band error.  The first string is a URI for
+	 *              the source of the error, the second string is the
+	 *              error message. */
 	dialog = gtk_message_dialog_new (
 		GTK_WINDOW (shell_window),
 		GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -166,6 +182,7 @@ cal_shell_sidebar_client_opened_cb (ECalShellSidebar *cal_shell_sidebar,
 	EShellView *shell_view;
 	EShellWindow *shell_window;
 	EShellSidebar *shell_sidebar;
+	const gchar *message;
 
 	shell_sidebar = E_SHELL_SIDEBAR (cal_shell_sidebar);
 	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
@@ -173,41 +190,138 @@ cal_shell_sidebar_client_opened_cb (ECalShellSidebar *cal_shell_sidebar,
 
 	if (status == E_CALENDAR_STATUS_AUTHENTICATION_FAILED ||
 		status == E_CALENDAR_STATUS_AUTHENTICATION_REQUIRED)
-		auth_cal_forget_password (client);
+		e_auth_cal_forget_password (client);
 
+	/* Handle errors. */
 	switch (status) {
 		case E_CALENDAR_STATUS_OK:
-			g_signal_handlers_disconnect_matched (
-				client, G_SIGNAL_MATCH_FUNC, 0, 0, NULL,
-				cal_shell_sidebar_client_opened_cb, NULL);
-
-			cal_shell_sidebar_emit_status_message (
-				cal_shell_sidebar, _("Loading calendars"));
-			cal_shell_sidebar_emit_client_added (
-				cal_shell_sidebar, client);
-			cal_shell_sidebar_emit_status_message (
-				cal_shell_sidebar, NULL);
 			break;
 
 		case E_CALENDAR_STATUS_AUTHENTICATION_FAILED:
 			e_cal_open_async (client, FALSE);
-			break;
+			return;
 
 		case E_CALENDAR_STATUS_BUSY:
-			break;
+			return;
 
 		case E_CALENDAR_STATUS_REPOSITORY_OFFLINE:
 			e_alert_run_dialog_for_args (
 				GTK_WINDOW (shell_window),
 				"calendar:prompt-no-contents-offline-calendar",
 				NULL);
-			break;
+			/* fall through */
 
 		default:
-			cal_shell_sidebar_emit_client_removed (
-				cal_shell_sidebar, client);
-			break;
+			e_cal_shell_sidebar_remove_source (
+				cal_shell_sidebar,
+				e_cal_get_source (client));
+			return;
 	}
+
+	g_assert (status == E_CALENDAR_STATUS_OK);
+
+	g_signal_handlers_disconnect_matched (
+		client, G_SIGNAL_MATCH_FUNC, 0, 0, NULL,
+		cal_shell_sidebar_client_opened_cb, NULL);
+
+	message = _("Loading calendars");
+	cal_shell_sidebar_emit_status_message (cal_shell_sidebar, message);
+	cal_shell_sidebar_emit_client_added (cal_shell_sidebar, client);
+	cal_shell_sidebar_emit_status_message (cal_shell_sidebar, NULL);
+}
+
+static void
+cal_shell_sidebar_default_opened_cb (ECalShellSidebar *cal_shell_sidebar,
+                                     ECalendarStatus status,
+                                     ECal *client)
+{
+	EShellView *shell_view;
+	EShellSidebar *shell_sidebar;
+
+	shell_sidebar = E_SHELL_SIDEBAR (cal_shell_sidebar);
+	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
+
+	if (status == E_CALENDAR_STATUS_AUTHENTICATION_FAILED ||
+		status == E_CALENDAR_STATUS_AUTHENTICATION_REQUIRED)
+		e_auth_cal_forget_password (client);
+
+	/* Handle errors. */
+	switch (status) {
+		case E_CALENDAR_STATUS_OK:
+			break;
+
+		case E_CALENDAR_STATUS_AUTHENTICATION_FAILED:
+			e_cal_open_async (client, FALSE);
+			return;
+
+		case E_CALENDAR_STATUS_BUSY:
+			return;
+
+		default:
+			e_cal_shell_sidebar_remove_source (
+				cal_shell_sidebar,
+				e_cal_get_source (client));
+			return;
+	}
+
+	g_assert (status == E_CALENDAR_STATUS_OK);
+
+	g_signal_handlers_disconnect_matched (
+		client, G_SIGNAL_MATCH_FUNC, 0, 0, NULL,
+		cal_shell_sidebar_default_opened_cb, NULL);
+
+	g_object_notify (G_OBJECT (cal_shell_sidebar), "default-client");
+}
+
+static void
+cal_shell_sidebar_set_default (ECalShellSidebar *cal_shell_sidebar,
+                               ESource *source)
+{
+	EShellView *shell_view;
+	EShellContent *shell_content;
+	EShellSidebar *shell_sidebar;
+	ECalShellContent *cal_shell_content;
+	ECalSourceType source_type;
+	GHashTable *client_table;
+	ECalModel *model;
+	ECal *client;
+	icaltimezone *timezone;
+	const gchar *uid;
+
+	source_type = E_CAL_SOURCE_TYPE_EVENT;
+	client_table = cal_shell_sidebar->priv->client_table;
+
+	uid = e_source_peek_uid (source);
+	client = g_hash_table_lookup (client_table, uid);
+
+	if (cal_shell_sidebar->priv->default_client != NULL)
+		g_object_unref (cal_shell_sidebar->priv->default_client);
+
+	if (client != NULL)
+		g_object_ref (client);
+	else
+		client = e_auth_new_cal_from_source (source, source_type);
+
+	cal_shell_sidebar->priv->default_client = client;
+	g_return_if_fail (client != NULL);
+
+	g_signal_connect_swapped (
+		client, "cal-opened",
+		G_CALLBACK (cal_shell_sidebar_default_opened_cb),
+		cal_shell_sidebar);
+
+	/* FIXME Sidebar should not be accessing the EShellContent.
+	 *       This probably needs to be moved to ECalShellView. */
+	shell_sidebar = E_SHELL_SIDEBAR (cal_shell_sidebar);
+	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
+	shell_content = e_shell_view_get_shell_content (shell_view);
+
+	cal_shell_content = E_CAL_SHELL_CONTENT (shell_content);
+	model = e_cal_shell_content_get_model (cal_shell_content);
+	timezone = e_cal_model_get_timezone (model);
+
+	e_cal_set_default_timezone (client, timezone, NULL);
+	e_cal_open_async (client, FALSE);
 }
 
 static void
@@ -295,6 +409,91 @@ cal_shell_sidebar_primary_selection_changed_cb (ECalShellSidebar *cal_shell_side
 	e_shell_settings_set_string (
 		shell_settings, "cal-primary-calendar",
 		e_source_peek_uid (source));
+
+	cal_shell_sidebar_set_default (cal_shell_sidebar, source);
+}
+
+static void
+cal_shell_sidebar_restore_state_cb (EShellWindow *shell_window,
+                                    EShellView *shell_view,
+                                    EShellSidebar *shell_sidebar)
+{
+	ECalShellSidebarPrivate *priv;
+	EShell *shell;
+	EShellBackend *shell_backend;
+	EShellSettings *shell_settings;
+	ESourceSelector *selector;
+	ESourceList *source_list;
+	ESource *source;
+	GConfBridge *bridge;
+	GtkTreeModel *model;
+	GSList *list, *iter;
+	GObject *object;
+	const gchar *key;
+	gchar *uid;
+
+	priv = E_CAL_SHELL_SIDEBAR_GET_PRIVATE (shell_sidebar);
+
+	shell = e_shell_window_get_shell (shell_window);
+	shell_settings = e_shell_get_shell_settings (shell);
+
+	shell_backend = e_shell_view_get_shell_backend (shell_view);
+	g_return_if_fail (E_IS_CAL_SHELL_BACKEND (shell_backend));
+
+	selector = E_SOURCE_SELECTOR (priv->selector);
+	model = gtk_tree_view_get_model (GTK_TREE_VIEW (selector));
+
+	source_list = e_cal_shell_backend_get_source_list (
+		E_CAL_SHELL_BACKEND (shell_backend));
+
+	g_signal_connect_swapped (
+		model, "row-changed",
+		G_CALLBACK (cal_shell_sidebar_row_changed_cb),
+		shell_sidebar);
+
+	g_signal_connect_swapped (
+		selector, "primary-selection-changed",
+		G_CALLBACK (cal_shell_sidebar_primary_selection_changed_cb),
+		shell_sidebar);
+
+	source = NULL;
+	uid = e_shell_settings_get_string (
+		shell_settings, "cal-primary-calendar");
+	if (uid != NULL)
+		source = e_source_list_peek_source_by_uid (source_list, uid);
+	if (source == NULL)
+		source = e_source_list_peek_source_any (source_list);
+	if (source != NULL)
+		e_source_selector_set_primary_selection (selector, source);
+	g_free (uid);
+
+	list = calendar_config_get_calendars_selected ();
+	for (iter = list; iter != NULL; iter = iter->next) {
+		uid = iter->data;
+		source = e_source_list_peek_source_by_uid (source_list, uid);
+		g_free (uid);
+
+		if (source == NULL)
+			continue;
+
+		e_source_selector_select_source (selector, source);
+	}
+	g_slist_free (list);
+
+	/* Listen for subsequent changes to the selector. */
+
+	g_signal_connect_swapped (
+		selector, "selection-changed",
+		G_CALLBACK (cal_shell_sidebar_selection_changed_cb),
+		shell_sidebar);
+
+	/* Bind GObject properties to GConf keys. */
+
+	bridge = gconf_bridge_get ();
+
+	object = G_OBJECT (priv->paned);
+	key = "/apps/evolution/calendar/display/date_navigator_vpane_position";
+	gconf_bridge_bind_property_delayed (bridge, key, object, "vposition");
 }
 
 static void
@@ -306,13 +505,22 @@ cal_shell_sidebar_get_property (GObject *object,
 	switch (property_id) {
 		case PROP_DATE_NAVIGATOR:
 			g_value_set_object (
-				value, e_cal_shell_sidebar_get_date_navigator (
+				value,
+				e_cal_shell_sidebar_get_date_navigator (
+				E_CAL_SHELL_SIDEBAR (object)));
+			return;
+
+		case PROP_DEFAULT_CLIENT:
+			g_value_set_object (
+				value,
+				e_cal_shell_sidebar_get_default_client (
 				E_CAL_SHELL_SIDEBAR (object)));
 			return;
 
 		case PROP_SELECTOR:
 			g_value_set_object (
-				value, e_cal_shell_sidebar_get_selector (
+				value,
+				e_cal_shell_sidebar_get_selector (
 				E_CAL_SHELL_SIDEBAR (object)));
 			return;
 	}
@@ -342,6 +550,11 @@ cal_shell_sidebar_dispose (GObject *object)
 		priv->date_navigator = NULL;
 	}
 
+	if (priv->default_client != NULL) {
+		g_object_unref (priv->default_client);
+		priv->default_client = NULL;
+	}
+
 	g_hash_table_remove_all (priv->client_table);
 
 	/* Chain up to parent's dispose() method. */
@@ -367,21 +580,15 @@ cal_shell_sidebar_constructed (GObject *object)
 	ECalShellSidebarPrivate *priv;
 	EShell *shell;
 	EShellView *shell_view;
+	EShellWindow *shell_window;
 	EShellBackend *shell_backend;
 	EShellSidebar *shell_sidebar;
 	EShellSettings *shell_settings;
-	ESourceSelector *selector;
 	ESourceList *source_list;
-	ESource *source;
 	ECalendarItem *calitem;
-	GConfBridge *bridge;
-	GtkTreeModel *model;
 	GtkWidget *container;
 	GtkWidget *widget;
 	AtkObject *a11y;
-	GSList *list, *iter;
-	const gchar *key;
-	gchar *uid;
 
 	priv = E_CAL_SHELL_SIDEBAR_GET_PRIVATE (object);
 
@@ -391,6 +598,7 @@ cal_shell_sidebar_constructed (GObject *object)
 	shell_sidebar = E_SHELL_SIDEBAR (object);
 	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
 	shell_backend = e_shell_view_get_shell_backend (shell_view);
+	shell_window = e_shell_view_get_shell_window (shell_view);
 
 	shell = e_shell_backend_get_shell (shell_backend);
 	shell_settings = e_shell_get_shell_settings (shell);
@@ -444,59 +652,12 @@ cal_shell_sidebar_constructed (GObject *object)
 		shell_settings, "cal-week-start-day",
 		calitem, "week-start-day");
 
-	/* Restore the selector state from the last session. */
-
-	selector = E_SOURCE_SELECTOR (priv->selector);
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (selector));
-
-	g_signal_connect_swapped (
-		model, "row-changed",
-		G_CALLBACK (cal_shell_sidebar_row_changed_cb),
-		object);
-
-	source = NULL;
-	uid = e_shell_settings_get_string (
-		shell_settings, "cal-primary-calendar");
-	if (uid != NULL)
-		source = e_source_list_peek_source_by_uid (source_list, uid);
-	if (source == NULL)
-		source = e_source_list_peek_source_any (source_list);
-	if (source != NULL)
-		e_source_selector_set_primary_selection (selector, source);
-	g_free (uid);
-
-	list = calendar_config_get_calendars_selected ();
-	for (iter = list; iter != NULL; iter = iter->next) {
-		uid = iter->data;
-		source = e_source_list_peek_source_by_uid (source_list, uid);
-		g_free (uid);
-
-		if (source == NULL)
-			continue;
-
-		e_source_selector_select_source (selector, source);
-	}
-	g_slist_free (list);
-
-	/* Listen for subsequent changes to the selector. */
-
-	g_signal_connect_swapped (
-		selector, "selection-changed",
-		G_CALLBACK (cal_shell_sidebar_selection_changed_cb),
-		object);
-
-	g_signal_connect_swapped (
-		selector, "primary-selection-changed",
-		G_CALLBACK (cal_shell_sidebar_primary_selection_changed_cb),
-		object);
-
-	/* Bind GObject properties to GConf keys. */
-
-	bridge = gconf_bridge_get ();
-
-	object = G_OBJECT (priv->paned);
-	key = "/apps/evolution/calendar/display/date_navigator_vpane_position";
-	gconf_bridge_bind_property_delayed (bridge, key, object, "vposition");
+	/* Restore widget state from the last session once
+	 * the shell view is fully initialized and visible. */
+	g_signal_connect (
+		shell_window, "shell-view-created::calendar",
+		G_CALLBACK (cal_shell_sidebar_restore_state_cb),
+		shell_sidebar);
 }
 
 static guint32
@@ -562,10 +723,10 @@ cal_shell_sidebar_client_removed (ECalShellSidebar *cal_shell_sidebar,
 		NULL, NULL, cal_shell_sidebar);
 
 	source = e_cal_get_source (client);
-	e_source_selector_unselect_source (selector, source);
-
 	uid = e_source_peek_uid (source);
+
 	g_hash_table_remove (client_table, uid);
+	e_source_selector_unselect_source (selector, source);
 
 	cal_shell_sidebar_emit_status_message (cal_shell_sidebar, NULL);
 }
@@ -595,18 +756,28 @@ cal_shell_sidebar_class_init (ECalShellSidebarClass *class)
 		PROP_DATE_NAVIGATOR,
 		g_param_spec_object (
 			"date-navigator",
-			_("Date Navigator Widget"),
-			_("This widget displays a miniature calendar"),
+			"Date Navigator Widget",
+			"This widget displays a miniature calendar",
 			E_TYPE_CALENDAR,
 			G_PARAM_READABLE));
 
+	g_object_class_install_property (
+		object_class,
+		PROP_DEFAULT_CLIENT,
+		g_param_spec_object (
+			"default-client",
+			"Default Calendar Client",
+			"Default client for calendar operations",
+			E_TYPE_CAL,
+			G_PARAM_READABLE));
+
 	g_object_class_install_property (
 		object_class,
 		PROP_SELECTOR,
 		g_param_spec_object (
 			"selector",
-			_("Source Selector Widget"),
-			_("This widget displays groups of calendars"),
+			"Source Selector Widget",
+			"This widget displays groups of calendars",
 			E_TYPE_SOURCE_SELECTOR,
 			G_PARAM_READABLE));
 
@@ -718,6 +889,15 @@ e_cal_shell_sidebar_get_date_navigator (ECalShellSidebar *cal_shell_sidebar)
 	return E_CALENDAR (cal_shell_sidebar->priv->date_navigator);
 }
 
+ECal *
+e_cal_shell_sidebar_get_default_client (ECalShellSidebar *cal_shell_sidebar)
+{
+	g_return_val_if_fail (
+		E_IS_CAL_SHELL_SIDEBAR (cal_shell_sidebar), NULL);
+
+	return cal_shell_sidebar->priv->default_client;
+}
+
 ESourceSelector *
 e_cal_shell_sidebar_get_selector (ECalShellSidebar *cal_shell_sidebar)
 {
@@ -731,9 +911,17 @@ void
 e_cal_shell_sidebar_add_source (ECalShellSidebar *cal_shell_sidebar,
                                 ESource *source)
 {
+	EShellView *shell_view;
+	EShellContent *shell_content;
+	EShellSidebar *shell_sidebar;
+	ECalShellContent *cal_shell_content;
+	ECalSourceType source_type;
 	ESourceSelector *selector;
 	GHashTable *client_table;
+	ECalModel *model;
+	ECal *default_client;
 	ECal *client;
+	icaltimezone *timezone;
 	const gchar *uid;
 	const gchar *uri;
 	gchar *message;
@@ -741,7 +929,9 @@ e_cal_shell_sidebar_add_source (ECalShellSidebar *cal_shell_sidebar,
 	g_return_if_fail (E_IS_CAL_SHELL_SIDEBAR (cal_shell_sidebar));
 	g_return_if_fail (E_IS_SOURCE (source));
 
+	source_type = E_CAL_SOURCE_TYPE_EVENT;
 	client_table = cal_shell_sidebar->priv->client_table;
+	default_client = cal_shell_sidebar->priv->default_client;
 	selector = e_cal_shell_sidebar_get_selector (cal_shell_sidebar);
 
 	uid = e_source_peek_uid (source);
@@ -750,7 +940,20 @@ e_cal_shell_sidebar_add_source (ECalShellSidebar *cal_shell_sidebar,
 	if (client != NULL)
 		return;
 
-	client = auth_new_cal_from_source (source, E_CAL_SOURCE_TYPE_EVENT);
+	if (default_client != NULL) {
+		ESource *default_source;
+		const gchar *default_uid;
+
+		default_source = e_cal_get_source (default_client);
+		default_uid = e_source_peek_uid (default_source);
+
+		if (g_strcmp0 (uid, default_uid) == 0)
+			client = g_object_ref (default_client);
+	}
+
+	if (client == NULL)
+		client = e_auth_new_cal_from_source (source, source_type);
+
 	g_return_if_fail (client != NULL);
 
 	g_signal_connect_swapped (
@@ -767,6 +970,7 @@ e_cal_shell_sidebar_add_source (ECalShellSidebar *cal_shell_sidebar,
 	e_source_selector_select_source (selector, source);
 
 	uri = e_cal_get_uri (client);
+	/* Translators: The string field is a URI. */
 	message = g_strdup_printf (_("Opening calendar at %s"), uri);
 	cal_shell_sidebar_emit_status_message (cal_shell_sidebar, message);
 	g_free (message);
@@ -776,6 +980,17 @@ e_cal_shell_sidebar_add_source (ECalShellSidebar *cal_shell_sidebar,
 		G_CALLBACK (cal_shell_sidebar_client_opened_cb),
 		cal_shell_sidebar);
 
+	/* FIXME Sidebar should not be accessing the EShellContent.
+	 *       This probably needs to be moved to ECalShellView. */
+	shell_sidebar = E_SHELL_SIDEBAR (cal_shell_sidebar);
+	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
+	shell_content = e_shell_view_get_shell_content (shell_view);
+
+	cal_shell_content = E_CAL_SHELL_CONTENT (shell_content);
+	model = e_cal_shell_content_get_model (cal_shell_content);
+	timezone = e_cal_model_get_timezone (model);
+
+	e_cal_set_default_timezone (client, timezone, NULL);
 	e_cal_open_async (client, FALSE);
 }
 
