@@ -280,7 +280,6 @@ cal_shell_view_update_actions (EShellView *shell_view)
 	GnomeCalendarViewType view_type;
 	GnomeCalendar *calendar;
 	ECalendarView *view;
-	ECalModel *model;
 	GtkAction *action;
 	GList *list, *iter;
 	gboolean sensitive;
@@ -291,80 +290,112 @@ cal_shell_view_update_actions (EShellView *shell_view)
 	gboolean can_delete_primary_source;
 	gboolean editable = TRUE;
 	gboolean has_primary_source;
-	gboolean primary_source_is_system;
 	gboolean recurring = FALSE;
 	gboolean is_instance = FALSE;
 	gboolean is_meeting = FALSE;
 	gboolean is_delegatable = FALSE;
-	gboolean clipboard_has_calendar;
 	gboolean refresh_supported = FALSE;
 
+	/* Chain up to parent's update_actions() method. */
+	E_SHELL_VIEW_CLASS (parent_class)->update_actions (shell_view);
+
 	priv = E_CAL_SHELL_VIEW_GET_PRIVATE (shell_view);
 
 	shell_window = e_shell_view_get_shell_window (shell_view);
 
+	if (e_shell_get_express_mode(e_shell_get_default())) {
+		GtkWidget *widget, *item;
+		GdkScreen *scr;
+		gint monitor;
+		GdkRectangle rect;
+
+		/* Hack: Get rid of New and Send/Receive in toolbar
+		 * while in express mode */
+		widget = e_shell_window_get_managed_widget (
+			shell_window, "/main-toolbar");
+
+		item = (GtkWidget *)gtk_toolbar_get_nth_item ((GtkToolbar *)widget, 0);
+		gtk_widget_hide(item);
+
+		widget = e_shell_window_get_managed_widget (
+			shell_window, "/main-menu");
+		gtk_widget_hide(widget);
+
+		item = e_shell_window_get_managed_widget (
+			shell_window, "/main-toolbar/send-receive");
+		gtk_widget_hide(item);
+
+		scr = gdk_screen_get_default ();
+		monitor = gdk_screen_get_monitor_at_window (
+			scr, gtk_widget_get_window (GTK_WIDGET (shell_window)));
+		gdk_screen_get_monitor_geometry (scr, monitor, &rect);
+
+		gtk_window_set_default_size (
+			GTK_WINDOW (shell_window), rect.width, rect.height);
+		gtk_window_set_decorated (
+			GTK_WINDOW (shell_window), FALSE);
+
+	}
 	cal_shell_content = priv->cal_shell_content;
 	calendar = e_cal_shell_content_get_calendar (cal_shell_content);
 	view_type = gnome_calendar_get_view (calendar);
 	view = gnome_calendar_get_calendar_view (calendar, view_type);
-	model = e_calendar_view_get_model (view);
 
 	list = e_calendar_view_get_selected_events (view);
 	n_selected = g_list_length (list);
 
 	for (iter = list; iter != NULL; iter = iter->next) {
 		ECalendarViewEvent *event = iter->data;
+		ECal *client;
+		ECalComponent *comp;
+		icalcomponent *icalcomp;
+		gchar *user_email = NULL;
+		gboolean user_org = FALSE;
 		gboolean read_only = TRUE;
 
 		if (!event || !event->comp_data)
 			continue;
 
-		e_cal_is_read_only (event->comp_data->client, &read_only, NULL);
+		client = event->comp_data->client;
+		icalcomp = event->comp_data->icalcomp;
+
+		e_cal_is_read_only (client, &read_only, NULL);
 		editable = editable && !read_only;
 
-		if (e_cal_util_component_has_recurrences (event->comp_data->icalcomp))
-			recurring = TRUE;
+		is_instance |= e_cal_util_component_is_instance (icalcomp);
 
-		if (e_cal_util_component_is_instance (event->comp_data->icalcomp)) {
-			recurring = TRUE;
-			is_instance = TRUE;
-		}
+		recurring |=
+			e_cal_util_component_is_instance (icalcomp) ||
+			e_cal_util_component_has_recurrences (icalcomp);
 
-		if (iter == list && !iter->next) {
-			ECalComponent *comp;
-			gchar *user_email = NULL;
-			gboolean user_org = FALSE;
+		/* The following tests only apply if one event is selected. */
+		if (iter != list || n_selected > 1)
+			continue;
 
-			comp = e_cal_component_new ();
-			e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (event->comp_data->icalcomp));
-			user_email = itip_get_comp_attendee (comp, event->comp_data->client);
+		comp = e_cal_component_new ();
+		e_cal_component_set_icalcomponent (
+			comp, icalcomponent_new_clone (icalcomp));
+		user_email = itip_get_comp_attendee (comp, client);
 
-			is_meeting = e_cal_util_component_has_attendee (event->comp_data->icalcomp);
+		is_meeting = e_cal_util_component_has_attendee (icalcomp);
 
-			if (e_cal_util_component_has_organizer (event->comp_data->icalcomp)) {
-				if (itip_organizer_is_user (comp, event->comp_data->client)) {
-					user_org = TRUE;
-				}
-			}
+		user_org =
+			e_cal_util_component_has_organizer (icalcomp) &&
+			itip_organizer_is_user (comp, client);
 
-			if (e_cal_get_static_capability (event->comp_data->client, CAL_STATIC_CAPABILITY_DELEGATE_SUPPORTED)) {
-				if (e_cal_get_static_capability (event->comp_data->client, CAL_STATIC_CAPABILITY_DELEGATE_TO_MANY))
-					is_delegatable = TRUE;
-				else if (!user_org && !is_delegated (event->comp_data->icalcomp, user_email))
-					is_delegatable = TRUE;
-			}
+		is_delegatable =
+			e_cal_get_static_capability (
+				client, CAL_STATIC_CAPABILITY_DELEGATE_SUPPORTED) &&
+			((e_cal_get_static_capability (
+				client, CAL_STATIC_CAPABILITY_DELEGATE_TO_MANY)) ||
+			(!user_org && !is_delegated (icalcomp, user_email)));
 
-			g_free (user_email);
-			g_object_unref (comp);
-		}
+		g_free (user_email);
+		g_object_unref (comp);
 	}
 
 	g_list_free (list);
 
-	clipboard_has_calendar =
-		e_clipboard_wait_is_calendar_available (
-		gtk_clipboard_get (GDK_SELECTION_CLIPBOARD));
-
 	shell_sidebar = e_shell_view_get_shell_sidebar (shell_view);
 	state = e_shell_sidebar_check_state (shell_sidebar);
 
@@ -372,8 +403,6 @@ cal_shell_view_update_actions (EShellView *shell_view)
 		(state & E_CAL_SHELL_SIDEBAR_HAS_PRIMARY_SOURCE);
 	can_delete_primary_source =
 		(state & E_CAL_SHELL_SIDEBAR_CAN_DELETE_PRIMARY_SOURCE);
-	primary_source_is_system =
-		(state & E_CAL_SHELL_SIDEBAR_PRIMARY_SOURCE_IS_SYSTEM);
 	refresh_supported =
 		(state & E_CAL_SHELL_SIDEBAR_SOURCE_SUPPORTS_REFRESH);
 
@@ -397,18 +426,6 @@ cal_shell_view_update_actions (EShellView *shell_view)
 	sensitive = can_delete_primary_source;
 	gtk_action_set_sensitive (action, sensitive);
 
-	action = ACTION (EVENT_CLIPBOARD_COPY);
-	sensitive = (n_selected > 0);
-	gtk_action_set_sensitive (action, sensitive);
-
-	action = ACTION (EVENT_CLIPBOARD_CUT);
-	sensitive = (n_selected > 0) && editable;
-	gtk_action_set_sensitive (action, sensitive);
-
-	action = ACTION (EVENT_CLIPBOARD_PASTE);
-	sensitive = editable && clipboard_has_calendar;
-	gtk_action_set_sensitive (action, sensitive);
-
 	action = ACTION (EVENT_DELEGATE);
 	sensitive =
 		(n_selected == 1) && editable &&
@@ -488,6 +505,10 @@ cal_shell_view_class_init (ECalShellViewClass *class,
 	shell_view_class->new_shell_sidebar = e_cal_shell_sidebar_new;
 	shell_view_class->execute_search = cal_shell_view_execute_search;
 	shell_view_class->update_actions = cal_shell_view_update_actions;
+
+	if (e_shell_get_express_mode(e_shell_get_default()))
+		shell_view_class->construct_searchbar = NULL;
+
 }
 
 static void
