@@ -22,10 +22,6 @@
 #include "e-mail-shell-backend.h"
 
 #include <glib/gi18n.h>
-#include <camel/camel-disco-store.h>
-#include <camel/camel-offline-store.h>
-#include <camel/camel-session.h>
-#include <camel/camel-url.h>
 
 #include "e-util/e-account-utils.h"
 #include "e-util/e-binding.h"
@@ -238,7 +234,6 @@ mail_shell_backend_sync_store_done_cb (CamelStore *store,
 
 static void
 mail_shell_backend_sync_store_cb (CamelStore *store,
-                                  const gchar *display_name,
                                   EMailShellBackend *mail_shell_backend)
 {
 	mail_shell_backend->priv->mail_sync_in_progress++;
@@ -409,32 +404,28 @@ mail_shell_backend_window_created_cb (EShell *shell,
                                       GtkWindow *window,
                                       EShellBackend *shell_backend)
 {
-	EShellSettings *shell_settings;
 	static gboolean first_time = TRUE;
 	const gchar *backend_name;
 
-	shell_settings = e_shell_get_shell_settings (shell);
-
 	/* This applies to both the composer and signature editor. */
 	if (GTKHTML_IS_EDITOR (window)) {
+		EShellSettings *shell_settings;
 		GList *spell_languages;
-
-		e_binding_new (
-			shell_settings, "composer-inline-spelling",
-			window, "inline-spelling");
-
-		e_binding_new (
-			shell_settings, "composer-magic-links",
-			window, "magic-links");
-
-		e_binding_new (
-			shell_settings, "composer-magic-smileys",
-			window, "magic-smileys");
+		gboolean active = TRUE;
 
 		spell_languages = e_load_spell_languages ();
 		gtkhtml_editor_set_spell_languages (
 			GTKHTML_EDITOR (window), spell_languages);
 		g_list_free (spell_languages);
+
+		shell_settings = e_shell_get_shell_settings (shell);
+
+		/* Express mode does not honor this setting. */
+		if (!e_shell_get_express_mode (shell))
+			active = e_shell_settings_get_boolean (
+				shell_settings, "composer-format-html");
+
+		gtkhtml_editor_set_html_mode (GTKHTML_EDITOR (window), active);
 	}
 
 	if (E_IS_MSG_COMPOSER (window)) {
