@@ -29,17 +29,6 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <gconf/gconf-client.h>
-#include <camel/camel-stream.h>
-#include <camel/camel-stream-mem.h>
-#include <camel/camel-medium.h>
-#include <camel/camel-mime-utils.h>
-#include <camel/camel-mime-message.h>
-#include <camel/camel-folder.h>
-#include <camel/camel-vee-folder.h>
-#include <camel/camel-multipart.h>
-#include <camel/camel-service.h>
-#include <camel/camel-store.h>
-#include <camel/camel-db.h>
 #include <libecal/e-cal.h>
 #include <libecal/e-cal-time-util.h>
 #include <libedataserverui/e-source-selector.h>
@@ -52,7 +41,7 @@
 #include <mail/mail-tools.h>
 #include <mail/mail-mt.h>
 #include <libedataserver/e-account-list.h>
-#include <e-util/e-alert.h>
+#include <e-util/e-alert-dialog.h>
 #include <calendar/gui/calendar-config.h>
 #include <calendar/gui/itip-utils.h>
 #include <calendar/common/authentication.h>
@@ -144,6 +133,7 @@ struct _itip_puri {
 void format_itip (EPlugin *ep, EMFormatHookTarget *target);
 GtkWidget *itip_formatter_page_factory (EPlugin *ep, EConfigHookItemFactoryData *hook_data);
 static void itip_attachment_frame(EMFormat *emf, CamelStream *stream, EMFormatPURI *puri);
+gint e_plugin_lib_enable (EPlugin *ep, gint enable);
 
 typedef struct {
 	struct _itip_puri *puri;
@@ -159,6 +149,12 @@ typedef void (* FormatItipOpenFunc) (ECal *ecal, ECalendarStatus status, gpointe
 
 static gboolean check_is_instance (icalcomponent *icalcomp);
 
+gint
+e_plugin_lib_enable (EPlugin *ep, gint enable)
+{
+	return 0;
+}
+
 static icalproperty *
 find_attendee (icalcomponent *ical_comp, const gchar *address)
 {
@@ -475,6 +471,23 @@ set_buttons_sensitive (struct _itip_puri *pitip)
 	itip_view_set_buttons_sensitive (ITIP_VIEW (pitip->view), pitip->current_ecal != NULL && !read_only);
 }
 
+static void
+add_failed_to_load_msg (ItipView *view, ESource *source, ECalendarStatus status)
+{
+	gchar *msg, *msg_full;
+
+	g_return_if_fail (view != NULL);
+	g_return_if_fail (source != NULL);
+
+	msg = g_strdup_printf (_("Failed to load the calendar '%s'"), e_source_peek_name (source));
+	msg_full = g_strconcat (msg, " (", e_cal_get_error_message (status), ")", NULL);
+
+	itip_view_add_lower_info_item (view, ITIP_VIEW_INFO_ITEM_TYPE_WARNING, msg_full);
+
+	g_free (msg_full);
+	g_free (msg);
+}
+
 static void
 cal_opened_cb (ECal *ecal, ECalendarStatus status, gpointer data)
 {
@@ -489,10 +502,8 @@ cal_opened_cb (ECal *ecal, ECalendarStatus status, gpointer data)
 
 	if (status != E_CALENDAR_STATUS_OK) {
 		d(printf ("Failed opening itip formatter calendar '%s' during non-search opening\n", e_source_peek_name (source)));
-		itip_view_add_lower_info_item_printf (ITIP_VIEW (pitip->view),
-						      ITIP_VIEW_INFO_ITEM_TYPE_WARNING,
-						      _("Failed to load the calendar '%s'"),
-						      e_source_peek_name (source));
+
+		add_failed_to_load_msg (ITIP_VIEW (pitip->view), source, status);
 
 		if (pitip->current_ecal == ecal) {
 			pitip->current_ecal = NULL;
@@ -545,7 +556,7 @@ start_calendar_server (struct _itip_puri *pitip, ESource *source, ECalSourceType
 		return ecal;
 	}
 
-	ecal = auth_new_cal_from_source (source, type);
+	ecal = e_auth_new_cal_from_source (source, type);
 
 	if (!ecal)
 		return NULL;
@@ -614,10 +625,8 @@ find_cal_opened_cb (ECal *ecal, ECalendarStatus status, gpointer data)
 		 * to find the item, this won't be cleared but the
 		 * selector might be shown */
 		d(printf ("Failed opening itip formatter calendar '%s' during search opening... ", e_source_peek_name (source)));
-		itip_view_add_lower_info_item_printf (ITIP_VIEW (pitip->view),
-						      ITIP_VIEW_INFO_ITEM_TYPE_WARNING,
-						      _("Failed to load the calendar '%s'"),
-						      e_source_peek_name (source));
+		add_failed_to_load_msg (ITIP_VIEW (pitip->view), source, status);
+
 		if (pitip->current_ecal == ecal) {
 			pitip->current_ecal = NULL;
 			itip_view_set_buttons_sensitive (ITIP_VIEW (pitip->view), FALSE);
@@ -807,6 +816,7 @@ find_server (struct _itip_puri *pitip, ECalComponent *comp)
 	GSList *groups, *l, *sources_conflict = NULL, *all_sources = NULL;
 	const gchar *uid;
 	gchar *rid = NULL;
+	CamelStore *parent_store;
 	CamelURL *url;
 	gchar *uri;
 	ESource *source = NULL, *current_source = NULL;
@@ -814,8 +824,10 @@ find_server (struct _itip_puri *pitip, ECalComponent *comp)
 	e_cal_component_get_uid (comp, &uid);
 	rid = e_cal_component_get_recurid_as_string (comp);
 
-        url = CAMEL_SERVICE (pitip->folder->parent_store)->url;
-        uri = camel_url_to_string (url, CAMEL_URL_HIDE_ALL);
+	parent_store = camel_folder_get_parent_store (pitip->folder);
+
+	url = CAMEL_SERVICE (parent_store)->url;
+	uri = camel_url_to_string (url, CAMEL_URL_HIDE_ALL);
 
 	itip_view_set_buttons_sensitive (ITIP_VIEW (pitip->view), FALSE);
 
@@ -866,7 +878,6 @@ find_server (struct _itip_puri *pitip, ECalComponent *comp)
 	}
 
 	for (; l != NULL; l = l->next) {
-		ECal *ecal;
 		source = l->data;
 
 		if (!fd) {
@@ -896,7 +907,7 @@ find_server (struct _itip_puri *pitip, ECalComponent *comp)
 		if (current_source == source)
 			pitip->current_ecal = start_calendar_server (pitip, source, pitip->type, find_cal_opened_cb, fd);
 		else
-			ecal = start_calendar_server (pitip, source, pitip->type, find_cal_opened_cb, fd);
+			start_calendar_server (pitip, source, pitip->type, find_cal_opened_cb, fd);
 
 	}
 
@@ -976,7 +987,7 @@ message_foreach_part (CamelMimePart *part, GSList **part_list)
 
 	*part_list = g_slist_append (*part_list, part);
 
-	containee = camel_medium_get_content_object (CAMEL_MEDIUM (part));
+	containee = camel_medium_get_content (CAMEL_MEDIUM (part));
 
 	if (containee == NULL)
 		return;
@@ -1519,7 +1530,7 @@ save_vcalendar_cb (GtkWidget *button, struct _itip_puri *pitip)
 
 	shell = e_shell_get_default ();
 	file = e_shell_run_save_dialog (
-		shell, _("Save Calendar"), suggestion, NULL, NULL);
+		shell, _("Save Calendar"), suggestion, "*.ics:text/calendar", NULL, NULL);
 	if (file == NULL)
 		return;
 
@@ -1973,8 +1984,10 @@ view_response_cb (GtkWidget *widget, ItipViewResponse response, gpointer data)
 				tag = camel_message_info_user_tag (mi, "recurrence-key");
 				camel_message_info_free (mi);
 				if (tag) {
-					gint i = 0, count;
+					CamelStore *parent_store;
 					GSList *list = NULL;
+					const gchar *full_name;
+					gint i = 0, count;
 
 					count = camel_folder_summary_count (pitip->folder->summary);
 					for (i = 0; i < count; i++) {
@@ -1993,7 +2006,10 @@ view_response_cb (GtkWidget *widget, ItipViewResponse response, gpointer data)
 						}
 						camel_message_info_free (mi);
 					}
-					camel_db_delete_uids (pitip->folder->parent_store->cdb_w, pitip->folder->full_name, list, NULL);
+
+					full_name = camel_folder_get_full_name (pitip->folder);
+					parent_store = camel_folder_get_parent_store (pitip->folder);
+					camel_db_delete_uids (parent_store->cdb_w, full_name, list, NULL);
 					g_slist_free (list);
 				}
 			} else {
@@ -2117,7 +2133,8 @@ in_proper_folder (CamelFolder *folder)
 
 	uri = mail_tools_folder_to_url (folder);
 
-	if (mail_folder_cache_get_folder_info_flags (folder, &flags)) {
+	if (mail_folder_cache_get_folder_info_flags (mail_folder_cache_get_default (),
+						     folder, &flags)) {
 		/* it should be neither trash nor junk folder, */
 		res = ((flags & CAMEL_FOLDER_TYPE_TRASH) !=  CAMEL_FOLDER_TYPE_TRASH &&
 		       (flags & CAMEL_FOLDER_TYPE_JUNK) != CAMEL_FOLDER_TYPE_JUNK &&
@@ -2297,7 +2314,7 @@ format_itip_object (EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObject
 	}
 
 	e_cal_component_get_summary (info->comp, &text);
-	itip_view_set_summary (ITIP_VIEW (info->view), text.value ? text.value : _("None"));
+	itip_view_set_summary (ITIP_VIEW (info->view), text.value ? text.value : C_("cal-itip", "None"));
 
 	e_cal_component_get_location (info->comp, &string);
 	itip_view_set_location (ITIP_VIEW (info->view), string);
@@ -2518,12 +2535,12 @@ puri_free (EMFormatPURI *puri)
 void
 format_itip (EPlugin *ep, EMFormatHookTarget *target)
 {
-	EMFormatHTMLPObject *pobj;
 	GConfClient *gconf;
 	gchar *classid;
 	struct _itip_puri *puri;
 	CamelDataWrapper *content;
-	CamelStream *mem;
+	CamelStream *stream;
+	GByteArray *byte_array;
 
 	classid = g_strdup_printf("itip:///%s", ((EMFormat *) target->format)->part_id->str);
 
@@ -2534,7 +2551,7 @@ format_itip (EPlugin *ep, EMFormatHookTarget *target)
 
 	puri = (struct _itip_puri *)em_format_add_puri(target->format, sizeof(struct _itip_puri), classid, target->part, itip_attachment_frame);
 
-	pobj = em_format_html_add_pobject ((EMFormatHTML *) target->format, sizeof (EMFormatHTMLPObject), classid, target->part, format_itip_object);
+	em_format_html_add_pobject ((EMFormatHTML *) target->format, sizeof (EMFormatHTMLPObject), classid, target->part, format_itip_object);
 
 	gconf = gconf_client_get_default ();
 	puri->delete_message = gconf_client_get_bool (gconf, GCONF_KEY_DELETE, NULL);
@@ -2548,15 +2565,19 @@ format_itip (EPlugin *ep, EMFormatHookTarget *target)
 	g_object_unref (gconf);
 
 	/* This is non-gui thread. Download the part for using in the main thread */
-	content = camel_medium_get_content_object ((CamelMedium *) target->part);
-	mem = camel_stream_mem_new ();
-	camel_data_wrapper_decode_to_stream (content, mem);
+	content = camel_medium_get_content ((CamelMedium *) target->part);
 
-	if (((CamelStreamMem *) mem)->buffer->len == 0)
+	byte_array = g_byte_array_new ();
+	stream = camel_stream_mem_new_with_byte_array (byte_array);
+	camel_data_wrapper_decode_to_stream (content, stream);
+
+	if (byte_array->len == 0)
 		puri->vcalendar = NULL;
 	else
-		puri->vcalendar = g_strndup ((gchar *)((CamelStreamMem *) mem)->buffer->data, ((CamelStreamMem *) mem)->buffer->len);
-	camel_object_unref (mem);
+		puri->vcalendar = g_strndup (
+			(gchar *) byte_array->data, byte_array->len);
+
+	g_object_unref (stream);
 
 	camel_stream_printf (target->stream, "<table border=0 width=\"100%%\" cellpadding=3><tr>");
 	camel_stream_printf (target->stream, "<td valign=top><object classid=\"%s\"></object></td><td width=100%% valign=top>", classid);
@@ -2641,7 +2662,7 @@ itip_formatter_page_factory (EPlugin *ep, EConfigHookItemFactoryData *hook_data)
 
 	/* Create a new notebook page */
 	page = gtk_vbox_new (FALSE, 0);
-	GTK_CONTAINER (page)->border_width = 12;
+	gtk_container_set_border_width (GTK_CONTAINER (page), 12);
 	tab_label = gtk_label_new (_("Calendar and Tasks"));
 	gtk_notebook_append_page (GTK_NOTEBOOK (hook_data->parent), page, tab_label);
 
@@ -2654,7 +2675,7 @@ itip_formatter_page_factory (EPlugin *ep, EConfigHookItemFactoryData *hook_data)
 	str = g_strdup_printf ("<span weight=\"bold\">%s</span>", _("General"));
 	gtk_label_set_markup (GTK_LABEL (frame_label), str);
 	g_free (str);
-	GTK_MISC (frame_label)->xalign = 0.0;
+	gtk_misc_set_alignment (GTK_MISC (frame_label), 0.0, 0.5);
 	gtk_box_pack_start (GTK_BOX (frame), frame_label, FALSE, FALSE, 0);
 
 	/* Indent/padding */
@@ -2680,7 +2701,7 @@ itip_formatter_page_factory (EPlugin *ep, EConfigHookItemFactoryData *hook_data)
 	str = g_strdup_printf ("<span weight=\"bold\">%s</span>", _("Conflict Search"));
 	gtk_label_set_markup (GTK_LABEL (frame_label), str);
 	g_free (str);
-	GTK_MISC (frame_label)->xalign = 0.0;
+	gtk_misc_set_alignment (GTK_MISC (frame_label), 0.0, 0.5);
 	gtk_box_pack_start (GTK_BOX (frame), frame_label, FALSE, FALSE, 0);
 
 	/* Indent/padding */
@@ -2729,7 +2750,7 @@ itip_attachment_frame(EMFormat *emf, CamelStream *stream, EMFormatPURI *puri)
 	struct _itip_puri *info = (struct _itip_puri *)puri;
 
 	d(printf("writing to frame content, handler is '%s'\n", info->handle->mime_type));
-	info->handle->handler(emf, stream, info->puri.part, info->handle);
+	info->handle->handler(emf, stream, info->puri.part, info->handle, FALSE);
 	camel_stream_close(stream);
 }
 
