@@ -32,7 +32,6 @@
 #include <mail/em-folder-tree.h>
 #include <mail/mail-ops.h>
 #include <mail/mail-mt.h>
-#include <camel/camel-vee-folder.h>
 
 #include <shell/e-shell-sidebar.h>
 #include <shell/e-shell-view.h>
@@ -44,14 +43,15 @@
 	N_("Do you want to mark messages as read in the current folder " \
 	   "only, or in the current folder as well as all subfolders?")
 
-enum {
-	MARK_ALL_READ_CANCEL,
-	MARK_ALL_READ_CURRENT_FOLDER,
-	MARK_ALL_READ_WITH_SUBFOLDERS
-};
-
 gboolean	e_plugin_ui_init		(GtkUIManager *ui_manager,
 						 EShellView *shell_view);
+gint e_plugin_lib_enable (EPlugin *ep, gint enable);
+
+gint
+e_plugin_lib_enable (EPlugin *ep, gint enable)
+{
+	return 0;
+}
 
 static void
 button_clicked_cb (GtkButton *button,
@@ -87,17 +87,18 @@ prompt_user (void)
 	GtkWidget *widget;
 	GtkWidget *vbox;
 	gchar *markup;
-	gint response, ret;
+	gint response;
 
 	dialog = gtk_dialog_new ();
-	gtk_widget_hide (GTK_DIALOG (dialog)->action_area);
+	widget = gtk_dialog_get_action_area (GTK_DIALOG (dialog));
+	gtk_widget_hide (widget);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_window_set_title (GTK_WINDOW (dialog), "");
 	g_signal_connect (
 		dialog, "map",
 		G_CALLBACK (gtk_widget_queue_resize), NULL);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 12);
-	vbox = GTK_DIALOG (dialog)->vbox;
+	vbox = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 
 	/* Table */
 	widget = gtk_table_new (3, 2, FALSE);
@@ -199,14 +200,7 @@ prompt_user (void)
 
 	gtk_widget_destroy (dialog);
 
-	if (response == GTK_RESPONSE_YES)
-		ret = MARK_ALL_READ_WITH_SUBFOLDERS;
-	else if (response == GTK_RESPONSE_NO)
-		ret = MARK_ALL_READ_CURRENT_FOLDER;
-	else
-		ret = MARK_ALL_READ_CANCEL;
-
-	return ret;
+	return response;
 }
 
 static gboolean
@@ -354,8 +348,9 @@ mar_got_folder (gchar *folder_uri,
                 gpointer data)
 {
 	CamelFolderInfo *folder_info;
-	CamelStore *store;
+	CamelStore *parent_store;
 	CamelException ex;
+	const gchar *full_name;
 	gint response;
 
 	/* FIXME we have to disable the menu item */
@@ -364,27 +359,29 @@ mar_got_folder (gchar *folder_uri,
 
 	camel_exception_init (&ex);
 
-	store = folder->parent_store;
+	full_name = camel_folder_get_full_name (folder);
+	parent_store = camel_folder_get_parent_store (folder);
+
 	folder_info = camel_store_get_folder_info (
-		store, folder->full_name,
+		parent_store, full_name,
 		CAMEL_STORE_FOLDER_INFO_RECURSIVE |
 		CAMEL_STORE_FOLDER_INFO_FAST, &ex);
 
 	if (camel_exception_is_set (&ex))
 		goto exit;
 
-	response = prompt_user ();
+	if (scan_folder_tree_for_unread (folder_uri) > 1)
+		response = prompt_user ();
+	else
+		response = GTK_RESPONSE_NO;
 
-	if (response == MARK_ALL_READ_CANCEL)
-		return;
-
-	if (response == MARK_ALL_READ_CURRENT_FOLDER)
+	if (response == GTK_RESPONSE_NO)
 		mark_all_as_read (folder);
-	else if (response == MARK_ALL_READ_WITH_SUBFOLDERS)
-		mar_all_sub_folders (store, folder_info, &ex);
+	else if (response == GTK_RESPONSE_YES)
+		mar_all_sub_folders (parent_store, folder_info, &ex);
 
 exit:
-	camel_store_free_folder_info (store, folder_info);
+	camel_store_free_folder_info (parent_store, folder_info);
 }
 
 static void
