@@ -19,9 +19,16 @@
  *
  */
 
+/**
+ * SECTION: e-shell-switcher
+ * @short_description: buttons for switching views
+ * @include: shell/e-shell-switcher.h
+ **/
+
 #include "e-shell-switcher.h"
 
 #include <glib/gi18n.h>
+#include <e-util/e-extensible.h>
 
 #define E_SHELL_SWITCHER_GET_PRIVATE(obj) \
 	(G_TYPE_INSTANCE_GET_PRIVATE \
@@ -50,13 +57,21 @@ enum {
 	LAST_SIGNAL
 };
 
-static gpointer parent_class;
 static guint signals[LAST_SIGNAL];
 
+/* Forward Declarations */
+static void shell_switcher_tool_shell_iface_init (GtkToolShellIface *iface);
+
+G_DEFINE_TYPE_WITH_CODE (
+	EShellSwitcher, e_shell_switcher, GTK_TYPE_BIN,
+	G_IMPLEMENT_INTERFACE (E_TYPE_EXTENSIBLE, NULL)
+	G_IMPLEMENT_INTERFACE (GTK_TYPE_TOOL_SHELL,
+		shell_switcher_tool_shell_iface_init))
+
 static gint
 shell_switcher_layout_actions (EShellSwitcher *switcher)
 {
-	GtkAllocation *allocation;
+	GtkAllocation allocation;
 	gint num_btns = g_list_length (switcher->priv->proxies), btns_per_row;
 	GList **rows, *p;
 	gboolean icons_only;
@@ -67,11 +82,12 @@ shell_switcher_layout_actions (EShellSwitcher *switcher)
 	gint x, y;
 	gint i;
 
-	allocation = &GTK_WIDGET (switcher)->allocation;
-	y = allocation->y + allocation->height;
+	gtk_widget_get_allocation (GTK_WIDGET (switcher), &allocation);
+
+	y = allocation.y + allocation.height;
 
 	if (num_btns == 0)
-		return allocation->height;
+		return allocation.height;
 
 	icons_only = (switcher->priv->style == GTK_TOOLBAR_ICONS);
 
@@ -86,7 +102,7 @@ shell_switcher_layout_actions (EShellSwitcher *switcher)
 	}
 
 	/* Figure out how many rows and columns we'll use. */
-	btns_per_row = MAX (1, allocation->width / (max_width + H_PADDING));
+	btns_per_row = MAX (1, allocation.width / (max_width + H_PADDING));
 	if (!icons_only) {
 		/* If using text buttons, we want to try to have a
 		 * completely filled-in grid, but if we can't, we want
@@ -123,12 +139,12 @@ shell_switcher_layout_actions (EShellSwitcher *switcher)
 	for (i = row_last; i >= 0; i--) {
 		gint len, extra_width;
 
-		x = H_PADDING + allocation->x;
+		x = H_PADDING + allocation.x;
 		y -= max_height;
 		len = g_list_length (rows[i]);
 		if (!icons_only)
 			extra_width =
-				(allocation->width - (len * max_width) -
+				(allocation.width - (len * max_width) -
 				(len * H_PADDING)) / len;
 		else
 			extra_width = 0;
@@ -152,7 +168,7 @@ shell_switcher_layout_actions (EShellSwitcher *switcher)
 		g_list_free (rows [i]);
 	g_free (rows);
 
-	return y - allocation->y;
+	return y - allocation.y;
 }
 
 static void
@@ -223,7 +239,7 @@ shell_switcher_dispose (GObject *object)
 	}
 
 	/* Chain up to parent's dispose() method. */
-	G_OBJECT_CLASS (parent_class)->dispose (object);
+	G_OBJECT_CLASS (e_shell_switcher_parent_class)->dispose (object);
 }
 
 static void
@@ -272,7 +288,7 @@ shell_switcher_size_allocate (GtkWidget *widget,
 
 	switcher = E_SHELL_SWITCHER (widget);
 
-	widget->allocation = *allocation;
+	gtk_widget_set_allocation (widget, allocation);
 
 	if (switcher->priv->toolbar_visible)
 		height = shell_switcher_layout_actions (switcher);
@@ -346,7 +362,8 @@ shell_switcher_remove (GtkContainer *container,
 	}
 
 	/* Chain up to parent's remove() method. */
-	GTK_CONTAINER_CLASS (parent_class)->remove (container, widget);
+	GTK_CONTAINER_CLASS (e_shell_switcher_parent_class)->remove (
+		container, widget);
 }
 
 static void
@@ -364,7 +381,7 @@ shell_switcher_forall (GtkContainer *container,
 			priv->proxies, (GFunc) callback, callback_data);
 
 	/* Chain up to parent's forall() method. */
-	GTK_CONTAINER_CLASS (parent_class)->forall (
+	GTK_CONTAINER_CLASS (e_shell_switcher_parent_class)->forall (
 		container, include_internals, callback, callback_data);
 }
 
@@ -410,13 +427,12 @@ shell_switcher_get_relief_style (GtkToolShell *shell)
 }
 
 static void
-shell_switcher_class_init (EShellSwitcherClass *class)
+e_shell_switcher_class_init (EShellSwitcherClass *class)
 {
 	GObjectClass *object_class;
 	GtkWidgetClass *widget_class;
 	GtkContainerClass *container_class;
 
-	parent_class = g_type_class_peek_parent (class);
 	g_type_class_add_private (class, sizeof (EShellSwitcherPrivate));
 
 	object_class = G_OBJECT_CLASS (class);
@@ -445,8 +461,8 @@ shell_switcher_class_init (EShellSwitcherClass *class)
 		PROP_TOOLBAR_STYLE,
 		g_param_spec_enum (
 			"toolbar-style",
-			_("Toolbar Style"),
-			_("The switcher's toolbar style"),
+			"Toolbar Style",
+			"The switcher's toolbar style",
 			GTK_TYPE_TOOLBAR_STYLE,
 			E_SHELL_SWITCHER_DEFAULT_TOOLBAR_STYLE,
 			G_PARAM_READWRITE |
@@ -462,8 +478,8 @@ shell_switcher_class_init (EShellSwitcherClass *class)
 		PROP_TOOLBAR_VISIBLE,
 		g_param_spec_boolean (
 			"toolbar-visible",
-			_("Toolbar Visible"),
-			_("Whether the switcher is visible"),
+			"Toolbar Visible",
+			"Whether the switcher is visible",
 			TRUE,
 			G_PARAM_READWRITE |
 			G_PARAM_CONSTRUCT));
@@ -487,11 +503,13 @@ shell_switcher_class_init (EShellSwitcherClass *class)
 }
 
 static void
-shell_switcher_init (EShellSwitcher *switcher)
+e_shell_switcher_init (EShellSwitcher *switcher)
 {
 	switcher->priv = E_SHELL_SWITCHER_GET_PRIVATE (switcher);
 
-	GTK_WIDGET_SET_FLAGS (switcher, GTK_NO_WINDOW);
+	gtk_widget_set_has_window (GTK_WIDGET (switcher), FALSE);
+
+	e_extensible_load_extensions (E_EXTENSIBLE (switcher));
 }
 
 static void
@@ -503,41 +521,6 @@ shell_switcher_tool_shell_iface_init (GtkToolShellIface *iface)
 	iface->get_relief_style = shell_switcher_get_relief_style;
 }
 
-GType
-e_shell_switcher_get_type (void)
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0)) {
-		static const GTypeInfo type_info = {
-			sizeof (EShellSwitcherClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) shell_switcher_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL,  /* class_data */
-			sizeof (EShellSwitcher),
-			0,     /* n_preallocs */
-			(GInstanceInitFunc) shell_switcher_init,
-			NULL   /* value_table */
-		};
-
-		static const GInterfaceInfo tool_shell_info = {
-			(GInterfaceInitFunc) shell_switcher_tool_shell_iface_init,
-			(GInterfaceFinalizeFunc) NULL,
-			NULL   /* interface_data */
-		};
-
-		type = g_type_register_static (
-			GTK_TYPE_BIN, "EShellSwitcher", &type_info, 0);
-
-		g_type_add_interface_static (
-			type, GTK_TYPE_TOOL_SHELL, &tool_shell_info);
-	}
-
-	return type;
-}
-
 /**
  * e_shell_switcher_new:
  *
@@ -562,7 +545,7 @@ tool_item_get_button (GtkWidget *widget)
 
 	g_return_val_if_fail (GTK_IS_TOOL_ITEM (widget), NULL);
 
-	child = GTK_BIN (widget)->child;
+	child = gtk_bin_get_child (GTK_BIN (widget));
 	if (child != NULL && GTK_IS_BUTTON (child))
 		return GTK_BUTTON (child);
 	else
