@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -23,8 +23,13 @@
 #ifndef _CERTIFICATE_MANAGER_H_
 #define _CERTIFICATE_MANAGER_H
 
-#include "evolution-config-control.h"
+#include <glib.h>
+#include <shell/e-shell.h>
 
-EvolutionConfigControl* certificate_manager_config_control_new (void);
+G_BEGIN_DECLS
+
+void		certificate_manager_config_init	(EShell *shell);
+
+G_END_DECLS
 
 #endif /* _CERTIFICATE_MANAGER_H_ */
