@@ -71,8 +71,8 @@ gal_define_views_dialog_class_init (GalDefineViewsDialogClass *klass)
 
 	g_object_class_install_property (object_class, PROP_COLLECTION,
 					 g_param_spec_object ("collection",
-							      _("Collection"),
-							      /*_( */"XXX blurb" /*)*/,
+							      "Collection",
+							      NULL,
 							      GAL_VIEW_COLLECTION_TYPE,
 							      G_PARAM_READWRITE));
 }
@@ -188,13 +188,18 @@ gdvd_cursor_changed_callback (GtkWidget *widget, GalDefineViewsDialog *dialog)
 	if (gtk_tree_selection_get_selected (gtk_tree_view_get_selection (dialog->treeview),
 					 &dialog->model,
 					 &iter)) {
+		GalViewClass *gvclass = NULL;
+
 		gtk_tree_model_get (dialog->model, &iter, COL_GALVIEW_DATA, &item, -1);
 
 		button = e_builder_get_widget (dialog->builder, "button-delete");
 		gtk_widget_set_sensitive (GTK_WIDGET (button), !item->built_in);
 
+		if (item->view)
+			gvclass = GAL_VIEW_GET_CLASS (item->view);
+
 		button = e_builder_get_widget (dialog->builder, "button-modify");
-		gtk_widget_set_sensitive (GTK_WIDGET (button), !item->built_in);
+		gtk_widget_set_sensitive (GTK_WIDGET (button), !item->built_in && gvclass && gvclass->edit != NULL);
 	}
 }
 
@@ -218,6 +223,8 @@ dialog_response (GalDefineViewsDialog *dialog, gint response_id, gpointer data)
 static void
 gal_define_views_dialog_init (GalDefineViewsDialog *dialog)
 {
+	GtkWidget *content_area;
+	GtkWidget *parent;
 	GtkWidget *widget;
 
 	dialog->collection = NULL;
@@ -231,11 +238,16 @@ gal_define_views_dialog_init (GalDefineViewsDialog *dialog)
 	}
 
 	g_object_ref (widget);
-	gtk_container_remove (GTK_CONTAINER (widget->parent), widget);
+
+	parent = gtk_widget_get_parent (widget);
+	gtk_container_remove (GTK_CONTAINER (parent), widget);
 	gtk_window_set_default_size (GTK_WINDOW (dialog), 360, 270);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
 	gtk_container_set_border_width (GTK_CONTAINER (widget), 6);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), widget, TRUE, TRUE, 0);
+
+	content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+	gtk_box_pack_start (GTK_BOX (content_area), widget, TRUE, TRUE, 0);
+
 	g_object_unref (widget);
 
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
